/*
C*GRAREA -- define a clipping window
C+
      SUBROUTINE GRAREA (IDENT,X0,Y0,XSIZE,YSIZE)
C
C GRPCKG: Define a rectangular window in the current plotting area. All
C graphics (except characters written with GRCHAR) will be blanked
C outside this window.  The default window is the full plotting area
C defined by default or by GRSETS.
C
C Arguments:
C
C IDENT (input, integer): the plot identifier, returned by GROPEN.
C X0, Y0 (input, real): the lower left corner of the window, in absolute
C       device coordinates.
C XSIZE, YSIZE (input, real): width and height of the window in absolute
C       coordinates; if either is negative, the window will be reset to
C       the full plotting area.
C--
C  1-Feb-1983 - [TJP].
C 25-Nov-1994 - use floating-point [TJP].
C-----------------------------------------------------------------------
*/

#include "pgplot.h"

#define MIN(a,b) (((a)<(b))?(a):(b))
#define MAX(a,b) (((a)>(b))?(a):(b))

void GRAREA (int *IDENT, float *X0, float *Y0, float *XSIZE, float *YSIZE) {
	int cident = *IDENT - 1;
	GRSLCT(IDENT);

	if ((*XSIZE <= 0.0) || (*YSIZE <= 0.0)) {
		grcm00_.grxmin[cident] = 0;
		grcm00_.grxmax[cident] = grcm00_.grxmxa[cident];
		grcm00_.grymin[cident] = 0;
		grcm00_.grymax[cident] = grcm00_.grymxa[cident];
	} else {
		grcm00_.grxmin[cident] = MAX(*X0, 0.0);
		grcm00_.grymin[cident] = MAX(*Y0, 0.0);
		grcm00_.grxmax[cident] = MIN(*XSIZE + *X0, (float)(grcm00_.grxmxa[cident]));
		grcm00_.grymax[cident] = MIN(*YSIZE + *Y0, (float)(grcm00_.grymxa[cident]));
	}
}
