C*PGSCRN -- set color representation by name
C%void cpgscrn(int ci, const char *name, int *ier);
C+
      SUBROUTINE PGSCRN(CI, NAME, IER)
      INTEGER CI
      CHARACTER*(*) NAME
      INTEGER IER
C
C Set color representation: i.e., define the color to be
C associated with a color index.  Ignored for devices which do not
C support variable color or intensity.  This is an alternative to
C routine PGSCR. The color representation is defined by name instead
C of (R,G,B) components.
C
C Color names are defined in an external file which is read the first
C time that PGSCRN is called. The name of the external file is
C found as follows:
C 1. if environment variable (logical name) PGPLOT_RGB is defined,
C    its value is used as the file name;
C 2. otherwise, if environment variable PGPLOT_DIR is defined, a
C    file "rgb.txt" in the directory named by this environment
C    variable is used;
C 3. otherwise, file "rgb.txt" in the current directory is used.
C If all of these fail to find a file, an error is reported and
C the routine does nothing.
C
C Each line of the file
C defines one color, with four blank- or tab-separated fields per
C line. The first three fields are the R, G, B components, which
C are integers in the range 0 (zero intensity) to 255 (maximum
C intensity). The fourth field is the color name. The color name
C may include embedded blanks. Example:
C
C 255   0   0 red
C 255 105 180 hot pink
C 255 255 255 white
C   0   0   0 black
C
C Arguments:
C  CI     (input)  : the color index to be defined, in the range 0-max.
C                    If the color index greater than the device
C                    maximum is specified, the call is ignored. Color
C                    index 0 applies to the background color.
C  NAME   (input)  : the name of the color to be associated with
C                    this color index. This name must be in the
C                    external file. The names are not case-sensitive.
C                    If the color is not listed in the file, the
C                    color representation is not changed.
C  IER    (output) : returns 0 if the routine was successful, 1
C                    if an error occurred (either the external file
C                    could not be read, or the requested color was
C                    not defined in the file).
C--
C 12-Oct-1992 [TJP]
C 31-May-1993 [TJP] use GROPTX to open file.
C  7-Nov-1994 [TJP] better error messages.
C-----------------------------------------------------------------------
      INTEGER MAXCOL
      PARAMETER (MAXCOL=1000)
      INTEGER I, IR, IG, IB, J, L, NCOL, UNIT, IOS
      INTEGER GRCTOI, GROPTX, GRTRIM
      REAL RR(MAXCOL), RG(MAXCOL), RB(MAXCOL)
      CHARACTER*20 CREQ, CNAME(MAXCOL)
      CHARACTER*255 TEXT
      SAVE NCOL, CNAME, RR, RG, RB
      DATA NCOL/0/
C
C On first call, read the database.
C
      IF (NCOL.EQ.0) THEN
          RR(1) = 255/255.0
          RG(1) = 250/255.0
          RB(1) = 250/255.0
          CNAME(1) = 'SNOW'
          RR(2) = 248/255.0
          RG(2) = 248/255.0
          RB(2) = 255/255.0
          CNAME(2) = 'GHOST WHITE'
          RR(3) = 248/255.0
          RG(3) = 248/255.0
          RB(3) = 255/255.0
          CNAME(3) = 'GHOSTWHITE'
          RR(4) = 245/255.0
          RG(4) = 245/255.0
          RB(4) = 245/255.0
          CNAME(4) = 'WHITE SMOKE'
          RR(5) = 245/255.0
          RG(5) = 245/255.0
          RB(5) = 245/255.0
          CNAME(5) = 'WHITESMOKE'
          RR(6) = 220/255.0
          RG(6) = 220/255.0
          RB(6) = 220/255.0
          CNAME(6) = 'GAINSBORO'
          RR(7) = 255/255.0
          RG(7) = 250/255.0
          RB(7) = 240/255.0
          CNAME(7) = 'FLORAL WHITE'
          RR(8) = 255/255.0
          RG(8) = 250/255.0
          RB(8) = 240/255.0
          CNAME(8) = 'FLORALWHITE'
          RR(9) = 253/255.0
          RG(9) = 245/255.0
          RB(9) = 230/255.0
          CNAME(9) = 'OLD LACE'
          RR(10) = 253/255.0
          RG(10) = 245/255.0
          RB(10) = 230/255.0
          CNAME(10) = 'OLDLACE'
          RR(11) = 250/255.0
          RG(11) = 240/255.0
          RB(11) = 230/255.0
          CNAME(11) = 'LINEN'
          RR(12) = 250/255.0
          RG(12) = 235/255.0
          RB(12) = 215/255.0
          CNAME(12) = 'ANTIQUE WHITE'
          RR(13) = 250/255.0
          RG(13) = 235/255.0
          RB(13) = 215/255.0
          CNAME(13) = 'ANTIQUEWHITE'
          RR(14) = 255/255.0
          RG(14) = 239/255.0
          RB(14) = 213/255.0
          CNAME(14) = 'PAPAYA WHIP'
          RR(15) = 255/255.0
          RG(15) = 239/255.0
          RB(15) = 213/255.0
          CNAME(15) = 'PAPAYAWHIP'
          RR(16) = 255/255.0
          RG(16) = 235/255.0
          RB(16) = 205/255.0
          CNAME(16) = 'BLANCHED ALMOND'
          RR(17) = 255/255.0
          RG(17) = 235/255.0
          RB(17) = 205/255.0
          CNAME(17) = 'BLANCHEDALMOND'
          RR(18) = 255/255.0
          RG(18) = 228/255.0
          RB(18) = 196/255.0
          CNAME(18) = 'BISQUE'
          RR(19) = 255/255.0
          RG(19) = 218/255.0
          RB(19) = 185/255.0
          CNAME(19) = 'PEACH PUFF'
          RR(20) = 255/255.0
          RG(20) = 218/255.0
          RB(20) = 185/255.0
          CNAME(20) = 'PEACHPUFF'
          RR(21) = 255/255.0
          RG(21) = 222/255.0
          RB(21) = 173/255.0
          CNAME(21) = 'NAVAJO WHITE'
          RR(22) = 255/255.0
          RG(22) = 222/255.0
          RB(22) = 173/255.0
          CNAME(22) = 'NAVAJOWHITE'
          RR(23) = 255/255.0
          RG(23) = 228/255.0
          RB(23) = 181/255.0
          CNAME(23) = 'MOCCASIN'
          RR(24) = 255/255.0
          RG(24) = 248/255.0
          RB(24) = 220/255.0
          CNAME(24) = 'CORNSILK'
          RR(25) = 255/255.0
          RG(25) = 255/255.0
          RB(25) = 240/255.0
          CNAME(25) = 'IVORY'
          RR(26) = 255/255.0
          RG(26) = 250/255.0
          RB(26) = 205/255.0
          CNAME(26) = 'LEMON CHIFFON'
          RR(27) = 255/255.0
          RG(27) = 250/255.0
          RB(27) = 205/255.0
          CNAME(27) = 'LEMONCHIFFON'
          RR(28) = 255/255.0
          RG(28) = 245/255.0
          RB(28) = 238/255.0
          CNAME(28) = 'SEASHELL'
          RR(29) = 240/255.0
          RG(29) = 255/255.0
          RB(29) = 240/255.0
          CNAME(29) = 'HONEYDEW'
          RR(30) = 245/255.0
          RG(30) = 255/255.0
          RB(30) = 250/255.0
          CNAME(30) = 'MINT CREAM'
          RR(31) = 245/255.0
          RG(31) = 255/255.0
          RB(31) = 250/255.0
          CNAME(31) = 'MINTCREAM'
          RR(32) = 240/255.0
          RG(32) = 255/255.0
          RB(32) = 255/255.0
          CNAME(32) = 'AZURE'
          RR(33) = 240/255.0
          RG(33) = 248/255.0
          RB(33) = 255/255.0
          CNAME(33) = 'ALICE BLUE'
          RR(34) = 240/255.0
          RG(34) = 248/255.0
          RB(34) = 255/255.0
          CNAME(34) = 'ALICEBLUE'
          RR(35) = 230/255.0
          RG(35) = 230/255.0
          RB(35) = 250/255.0
          CNAME(35) = 'LAVENDER'
          RR(36) = 255/255.0
          RG(36) = 240/255.0
          RB(36) = 245/255.0
          CNAME(36) = 'LAVENDER BLUSH'
          RR(37) = 255/255.0
          RG(37) = 240/255.0
          RB(37) = 245/255.0
          CNAME(37) = 'LAVENDERBLUSH'
          RR(38) = 255/255.0
          RG(38) = 228/255.0
          RB(38) = 225/255.0
          CNAME(38) = 'MISTY ROSE'
          RR(39) = 255/255.0
          RG(39) = 228/255.0
          RB(39) = 225/255.0
          CNAME(39) = 'MISTYROSE'
          RR(40) = 255/255.0
          RG(40) = 255/255.0
          RB(40) = 255/255.0
          CNAME(40) = 'WHITE'
          RR(41) = 0/255.0
          RG(41) = 0/255.0
          RB(41) = 0/255.0
          CNAME(41) = 'BLACK'
          RR(42) = 47/255.0
          RG(42) = 79/255.0
          RB(42) = 79/255.0
          CNAME(42) = 'DARK SLATE GRAY'
          RR(43) = 47/255.0
          RG(43) = 79/255.0
          RB(43) = 79/255.0
          CNAME(43) = 'DARKSLATEGRAY'
          RR(44) = 47/255.0
          RG(44) = 79/255.0
          RB(44) = 79/255.0
          CNAME(44) = 'DARK SLATE GREY'
          RR(45) = 47/255.0
          RG(45) = 79/255.0
          RB(45) = 79/255.0
          CNAME(45) = 'DARKSLATEGREY'
          RR(46) = 105/255.0
          RG(46) = 105/255.0
          RB(46) = 105/255.0
          CNAME(46) = 'DIM GRAY'
          RR(47) = 105/255.0
          RG(47) = 105/255.0
          RB(47) = 105/255.0
          CNAME(47) = 'DIMGRAY'
          RR(48) = 105/255.0
          RG(48) = 105/255.0
          RB(48) = 105/255.0
          CNAME(48) = 'DIM GREY'
          RR(49) = 105/255.0
          RG(49) = 105/255.0
          RB(49) = 105/255.0
          CNAME(49) = 'DIMGREY'
          RR(50) = 112/255.0
          RG(50) = 128/255.0
          RB(50) = 144/255.0
          CNAME(50) = 'SLATE GRAY'
          RR(51) = 112/255.0
          RG(51) = 128/255.0
          RB(51) = 144/255.0
          CNAME(51) = 'SLATEGRAY'
          RR(52) = 112/255.0
          RG(52) = 128/255.0
          RB(52) = 144/255.0
          CNAME(52) = 'SLATE GREY'
          RR(53) = 112/255.0
          RG(53) = 128/255.0
          RB(53) = 144/255.0
          CNAME(53) = 'SLATEGREY'
          RR(54) = 119/255.0
          RG(54) = 136/255.0
          RB(54) = 153/255.0
          CNAME(54) = 'LIGHT SLATE GRAY'
          RR(55) = 119/255.0
          RG(55) = 136/255.0
          RB(55) = 153/255.0
          CNAME(55) = 'LIGHTSLATEGRAY'
          RR(56) = 119/255.0
          RG(56) = 136/255.0
          RB(56) = 153/255.0
          CNAME(56) = 'LIGHT SLATE GREY'
          RR(57) = 119/255.0
          RG(57) = 136/255.0
          RB(57) = 153/255.0
          CNAME(57) = 'LIGHTSLATEGREY'
          RR(58) = 190/255.0
          RG(58) = 190/255.0
          RB(58) = 190/255.0
          CNAME(58) = 'GRAY'
          RR(59) = 190/255.0
          RG(59) = 190/255.0
          RB(59) = 190/255.0
          CNAME(59) = 'GREY'
          RR(60) = 211/255.0
          RG(60) = 211/255.0
          RB(60) = 211/255.0
          CNAME(60) = 'LIGHT GREY'
          RR(61) = 211/255.0
          RG(61) = 211/255.0
          RB(61) = 211/255.0
          CNAME(61) = 'LIGHTGREY'
          RR(62) = 211/255.0
          RG(62) = 211/255.0
          RB(62) = 211/255.0
          CNAME(62) = 'LIGHT GRAY'
          RR(63) = 211/255.0
          RG(63) = 211/255.0
          RB(63) = 211/255.0
          CNAME(63) = 'LIGHTGRAY'
          RR(64) = 25/255.0
          RG(64) = 25/255.0
          RB(64) = 112/255.0
          CNAME(64) = 'MIDNIGHT BLUE'
          RR(65) = 25/255.0
          RG(65) = 25/255.0
          RB(65) = 112/255.0
          CNAME(65) = 'MIDNIGHTBLUE'
          RR(66) = 0/255.0
          RG(66) = 0/255.0
          RB(66) = 128/255.0
          CNAME(66) = 'NAVY'
          RR(67) = 0/255.0
          RG(67) = 0/255.0
          RB(67) = 128/255.0
          CNAME(67) = 'NAVY BLUE'
          RR(68) = 0/255.0
          RG(68) = 0/255.0
          RB(68) = 128/255.0
          CNAME(68) = 'NAVYBLUE'
          RR(69) = 100/255.0
          RG(69) = 149/255.0
          RB(69) = 237/255.0
          CNAME(69) = 'CORNFLOWER BLUE'
          RR(70) = 100/255.0
          RG(70) = 149/255.0
          RB(70) = 237/255.0
          CNAME(70) = 'CORNFLOWERBLUE'
          RR(71) = 72/255.0
          RG(71) = 61/255.0
          RB(71) = 139/255.0
          CNAME(71) = 'DARK SLATE BLUE'
          RR(72) = 72/255.0
          RG(72) = 61/255.0
          RB(72) = 139/255.0
          CNAME(72) = 'DARKSLATEBLUE'
          RR(73) = 106/255.0
          RG(73) = 90/255.0
          RB(73) = 205/255.0
          CNAME(73) = 'SLATE BLUE'
          RR(74) = 106/255.0
          RG(74) = 90/255.0
          RB(74) = 205/255.0
          CNAME(74) = 'SLATEBLUE'
          RR(75) = 123/255.0
          RG(75) = 104/255.0
          RB(75) = 238/255.0
          CNAME(75) = 'MEDIUM SLATE BLUE'
          RR(76) = 123/255.0
          RG(76) = 104/255.0
          RB(76) = 238/255.0
          CNAME(76) = 'MEDIUMSLATEBLUE'
          RR(77) = 132/255.0
          RG(77) = 112/255.0
          RB(77) = 255/255.0
          CNAME(77) = 'LIGHT SLATE BLUE'
          RR(78) = 132/255.0
          RG(78) = 112/255.0
          RB(78) = 255/255.0
          CNAME(78) = 'LIGHTSLATEBLUE'
          RR(79) = 0/255.0
          RG(79) = 0/255.0
          RB(79) = 205/255.0
          CNAME(79) = 'MEDIUM BLUE'
          RR(80) = 0/255.0
          RG(80) = 0/255.0
          RB(80) = 205/255.0
          CNAME(80) = 'MEDIUMBLUE'
          RR(81) = 65/255.0
          RG(81) = 105/255.0
          RB(81) = 225/255.0
          CNAME(81) = 'ROYAL BLUE'
          RR(82) = 65/255.0
          RG(82) = 105/255.0
          RB(82) = 225/255.0
          CNAME(82) = 'ROYALBLUE'
          RR(83) = 0/255.0
          RG(83) = 0/255.0
          RB(83) = 255/255.0
          CNAME(83) = 'BLUE'
          RR(84) = 30/255.0
          RG(84) = 144/255.0
          RB(84) = 255/255.0
          CNAME(84) = 'DODGER BLUE'
          RR(85) = 30/255.0
          RG(85) = 144/255.0
          RB(85) = 255/255.0
          CNAME(85) = 'DODGERBLUE'
          RR(86) = 0/255.0
          RG(86) = 191/255.0
          RB(86) = 255/255.0
          CNAME(86) = 'DEEP SKY BLUE'
          RR(87) = 0/255.0
          RG(87) = 191/255.0
          RB(87) = 255/255.0
          CNAME(87) = 'DEEPSKYBLUE'
          RR(88) = 135/255.0
          RG(88) = 206/255.0
          RB(88) = 235/255.0
          CNAME(88) = 'SKY BLUE'
          RR(89) = 135/255.0
          RG(89) = 206/255.0
          RB(89) = 235/255.0
          CNAME(89) = 'SKYBLUE'
          RR(90) = 135/255.0
          RG(90) = 206/255.0
          RB(90) = 250/255.0
          CNAME(90) = 'LIGHT SKY BLUE'
          RR(91) = 135/255.0
          RG(91) = 206/255.0
          RB(91) = 250/255.0
          CNAME(91) = 'LIGHTSKYBLUE'
          RR(92) = 70/255.0
          RG(92) = 130/255.0
          RB(92) = 180/255.0
          CNAME(92) = 'STEEL BLUE'
          RR(93) = 70/255.0
          RG(93) = 130/255.0
          RB(93) = 180/255.0
          CNAME(93) = 'STEELBLUE'
          RR(94) = 176/255.0
          RG(94) = 196/255.0
          RB(94) = 222/255.0
          CNAME(94) = 'LIGHT STEEL BLUE'
          RR(95) = 176/255.0
          RG(95) = 196/255.0
          RB(95) = 222/255.0
          CNAME(95) = 'LIGHTSTEELBLUE'
          RR(96) = 173/255.0
          RG(96) = 216/255.0
          RB(96) = 230/255.0
          CNAME(96) = 'LIGHT BLUE'
          RR(97) = 173/255.0
          RG(97) = 216/255.0
          RB(97) = 230/255.0
          CNAME(97) = 'LIGHTBLUE'
          RR(98) = 176/255.0
          RG(98) = 224/255.0
          RB(98) = 230/255.0
          CNAME(98) = 'POWDER BLUE'
          RR(99) = 176/255.0
          RG(99) = 224/255.0
          RB(99) = 230/255.0
          CNAME(99) = 'POWDERBLUE'
          RR(100) = 175/255.0
          RG(100) = 238/255.0
          RB(100) = 238/255.0
          CNAME(100) = 'PALE TURQUOISE'
          RR(101) = 175/255.0
          RG(101) = 238/255.0
          RB(101) = 238/255.0
          CNAME(101) = 'PALETURQUOISE'
          RR(102) = 0/255.0
          RG(102) = 206/255.0
          RB(102) = 209/255.0
          CNAME(102) = 'DARK TURQUOISE'
          RR(103) = 0/255.0
          RG(103) = 206/255.0
          RB(103) = 209/255.0
          CNAME(103) = 'DARKTURQUOISE'
          RR(104) = 72/255.0
          RG(104) = 209/255.0
          RB(104) = 204/255.0
          CNAME(104) = 'MEDIUM TURQUOISE'
          RR(105) = 72/255.0
          RG(105) = 209/255.0
          RB(105) = 204/255.0
          CNAME(105) = 'MEDIUMTURQUOISE'
          RR(106) = 64/255.0
          RG(106) = 224/255.0
          RB(106) = 208/255.0
          CNAME(106) = 'TURQUOISE'
          RR(107) = 0/255.0
          RG(107) = 255/255.0
          RB(107) = 255/255.0
          CNAME(107) = 'CYAN'
          RR(108) = 224/255.0
          RG(108) = 255/255.0
          RB(108) = 255/255.0
          CNAME(108) = 'LIGHT CYAN'
          RR(109) = 224/255.0
          RG(109) = 255/255.0
          RB(109) = 255/255.0
          CNAME(109) = 'LIGHTCYAN'
          RR(110) = 95/255.0
          RG(110) = 158/255.0
          RB(110) = 160/255.0
          CNAME(110) = 'CADET BLUE'
          RR(111) = 95/255.0
          RG(111) = 158/255.0
          RB(111) = 160/255.0
          CNAME(111) = 'CADETBLUE'
          RR(112) = 102/255.0
          RG(112) = 205/255.0
          RB(112) = 170/255.0
          CNAME(112) = 'MEDIUM AQUAMARINE'
          RR(113) = 102/255.0
          RG(113) = 205/255.0
          RB(113) = 170/255.0
          CNAME(113) = 'MEDIUMAQUAMARINE'
          RR(114) = 127/255.0
          RG(114) = 255/255.0
          RB(114) = 212/255.0
          CNAME(114) = 'AQUAMARINE'
          RR(115) = 0/255.0
          RG(115) = 100/255.0
          RB(115) = 0/255.0
          CNAME(115) = 'DARK GREEN'
          RR(116) = 0/255.0
          RG(116) = 100/255.0
          RB(116) = 0/255.0
          CNAME(116) = 'DARKGREEN'
          RR(117) = 85/255.0
          RG(117) = 107/255.0
          RB(117) = 47/255.0
          CNAME(117) = 'DARK OLIVE GREEN'
          RR(118) = 85/255.0
          RG(118) = 107/255.0
          RB(118) = 47/255.0
          CNAME(118) = 'DARKOLIVEGREEN'
          RR(119) = 143/255.0
          RG(119) = 188/255.0
          RB(119) = 143/255.0
          CNAME(119) = 'DARK SEA GREEN'
          RR(120) = 143/255.0
          RG(120) = 188/255.0
          RB(120) = 143/255.0
          CNAME(120) = 'DARKSEAGREEN'
          RR(121) = 46/255.0
          RG(121) = 139/255.0
          RB(121) = 87/255.0
          CNAME(121) = 'SEA GREEN'
          RR(122) = 46/255.0
          RG(122) = 139/255.0
          RB(122) = 87/255.0
          CNAME(122) = 'SEAGREEN'
          RR(123) = 60/255.0
          RG(123) = 179/255.0
          RB(123) = 113/255.0
          CNAME(123) = 'MEDIUM SEA GREEN'
          RR(124) = 60/255.0
          RG(124) = 179/255.0
          RB(124) = 113/255.0
          CNAME(124) = 'MEDIUMSEAGREEN'
          RR(125) = 32/255.0
          RG(125) = 178/255.0
          RB(125) = 170/255.0
          CNAME(125) = 'LIGHT SEA GREEN'
          RR(126) = 32/255.0
          RG(126) = 178/255.0
          RB(126) = 170/255.0
          CNAME(126) = 'LIGHTSEAGREEN'
          RR(127) = 152/255.0
          RG(127) = 251/255.0
          RB(127) = 152/255.0
          CNAME(127) = 'PALE GREEN'
          RR(128) = 152/255.0
          RG(128) = 251/255.0
          RB(128) = 152/255.0
          CNAME(128) = 'PALEGREEN'
          RR(129) = 0/255.0
          RG(129) = 255/255.0
          RB(129) = 127/255.0
          CNAME(129) = 'SPRING GREEN'
          RR(130) = 0/255.0
          RG(130) = 255/255.0
          RB(130) = 127/255.0
          CNAME(130) = 'SPRINGGREEN'
          RR(131) = 124/255.0
          RG(131) = 252/255.0
          RB(131) = 0/255.0
          CNAME(131) = 'LAWN GREEN'
          RR(132) = 124/255.0
          RG(132) = 252/255.0
          RB(132) = 0/255.0
          CNAME(132) = 'LAWNGREEN'
          RR(133) = 0/255.0
          RG(133) = 255/255.0
          RB(133) = 0/255.0
          CNAME(133) = 'GREEN'
          RR(134) = 127/255.0
          RG(134) = 255/255.0
          RB(134) = 0/255.0
          CNAME(134) = 'CHARTREUSE'
          RR(135) = 0/255.0
          RG(135) = 250/255.0
          RB(135) = 154/255.0
          CNAME(135) = 'MEDIUM SPRING GREEN'
          RR(136) = 0/255.0
          RG(136) = 250/255.0
          RB(136) = 154/255.0
          CNAME(136) = 'MEDIUMSPRINGGREEN'
          RR(137) = 173/255.0
          RG(137) = 255/255.0
          RB(137) = 47/255.0
          CNAME(137) = 'GREEN YELLOW'
          RR(138) = 173/255.0
          RG(138) = 255/255.0
          RB(138) = 47/255.0
          CNAME(138) = 'GREENYELLOW'
          RR(139) = 50/255.0
          RG(139) = 205/255.0
          RB(139) = 50/255.0
          CNAME(139) = 'LIME GREEN'
          RR(140) = 50/255.0
          RG(140) = 205/255.0
          RB(140) = 50/255.0
          CNAME(140) = 'LIMEGREEN'
          RR(141) = 154/255.0
          RG(141) = 205/255.0
          RB(141) = 50/255.0
          CNAME(141) = 'YELLOW GREEN'
          RR(142) = 154/255.0
          RG(142) = 205/255.0
          RB(142) = 50/255.0
          CNAME(142) = 'YELLOWGREEN'
          RR(143) = 34/255.0
          RG(143) = 139/255.0
          RB(143) = 34/255.0
          CNAME(143) = 'FOREST GREEN'
          RR(144) = 34/255.0
          RG(144) = 139/255.0
          RB(144) = 34/255.0
          CNAME(144) = 'FORESTGREEN'
          RR(145) = 107/255.0
          RG(145) = 142/255.0
          RB(145) = 35/255.0
          CNAME(145) = 'OLIVE DRAB'
          RR(146) = 107/255.0
          RG(146) = 142/255.0
          RB(146) = 35/255.0
          CNAME(146) = 'OLIVEDRAB'
          RR(147) = 189/255.0
          RG(147) = 183/255.0
          RB(147) = 107/255.0
          CNAME(147) = 'DARK KHAKI'
          RR(148) = 189/255.0
          RG(148) = 183/255.0
          RB(148) = 107/255.0
          CNAME(148) = 'DARKKHAKI'
          RR(149) = 240/255.0
          RG(149) = 230/255.0
          RB(149) = 140/255.0
          CNAME(149) = 'KHAKI'
          RR(150) = 238/255.0
          RG(150) = 232/255.0
          RB(150) = 170/255.0
          CNAME(150) = 'PALE GOLDENROD'
          RR(151) = 238/255.0
          RG(151) = 232/255.0
          RB(151) = 170/255.0
          CNAME(151) = 'PALEGOLDENROD'
          RR(152) = 250/255.0
          RG(152) = 250/255.0
          RB(152) = 210/255.0
          CNAME(152) = 'LIGHT GOLDENROD YELL'
          RR(153) = 250/255.0
          RG(153) = 250/255.0
          RB(153) = 210/255.0
          CNAME(153) = 'LIGHTGOLDENRODYELLOW'
          RR(154) = 255/255.0
          RG(154) = 255/255.0
          RB(154) = 224/255.0
          CNAME(154) = 'LIGHT YELLOW'
          RR(155) = 255/255.0
          RG(155) = 255/255.0
          RB(155) = 224/255.0
          CNAME(155) = 'LIGHTYELLOW'
          RR(156) = 255/255.0
          RG(156) = 255/255.0
          RB(156) = 0/255.0
          CNAME(156) = 'YELLOW'
          RR(157) = 255/255.0
          RG(157) = 215/255.0
          RB(157) = 0/255.0
          CNAME(157) = 'GOLD'
          RR(158) = 238/255.0
          RG(158) = 221/255.0
          RB(158) = 130/255.0
          CNAME(158) = 'LIGHT GOLDENROD'
          RR(159) = 238/255.0
          RG(159) = 221/255.0
          RB(159) = 130/255.0
          CNAME(159) = 'LIGHTGOLDENROD'
          RR(160) = 218/255.0
          RG(160) = 165/255.0
          RB(160) = 32/255.0
          CNAME(160) = 'GOLDENROD'
          RR(161) = 184/255.0
          RG(161) = 134/255.0
          RB(161) = 11/255.0
          CNAME(161) = 'DARK GOLDENROD'
          RR(162) = 184/255.0
          RG(162) = 134/255.0
          RB(162) = 11/255.0
          CNAME(162) = 'DARKGOLDENROD'
          RR(163) = 188/255.0
          RG(163) = 143/255.0
          RB(163) = 143/255.0
          CNAME(163) = 'ROSY BROWN'
          RR(164) = 188/255.0
          RG(164) = 143/255.0
          RB(164) = 143/255.0
          CNAME(164) = 'ROSYBROWN'
          RR(165) = 205/255.0
          RG(165) = 92/255.0
          RB(165) = 92/255.0
          CNAME(165) = 'INDIAN RED'
          RR(166) = 205/255.0
          RG(166) = 92/255.0
          RB(166) = 92/255.0
          CNAME(166) = 'INDIANRED'
          RR(167) = 139/255.0
          RG(167) = 69/255.0
          RB(167) = 19/255.0
          CNAME(167) = 'SADDLE BROWN'
          RR(168) = 139/255.0
          RG(168) = 69/255.0
          RB(168) = 19/255.0
          CNAME(168) = 'SADDLEBROWN'
          RR(169) = 160/255.0
          RG(169) = 82/255.0
          RB(169) = 45/255.0
          CNAME(169) = 'SIENNA'
          RR(170) = 205/255.0
          RG(170) = 133/255.0
          RB(170) = 63/255.0
          CNAME(170) = 'PERU'
          RR(171) = 222/255.0
          RG(171) = 184/255.0
          RB(171) = 135/255.0
          CNAME(171) = 'BURLYWOOD'
          RR(172) = 245/255.0
          RG(172) = 245/255.0
          RB(172) = 220/255.0
          CNAME(172) = 'BEIGE'
          RR(173) = 245/255.0
          RG(173) = 222/255.0
          RB(173) = 179/255.0
          CNAME(173) = 'WHEAT'
          RR(174) = 244/255.0
          RG(174) = 164/255.0
          RB(174) = 96/255.0
          CNAME(174) = 'SANDY BROWN'
          RR(175) = 244/255.0
          RG(175) = 164/255.0
          RB(175) = 96/255.0
          CNAME(175) = 'SANDYBROWN'
          RR(176) = 210/255.0
          RG(176) = 180/255.0
          RB(176) = 140/255.0
          CNAME(176) = 'TAN'
          RR(177) = 210/255.0
          RG(177) = 105/255.0
          RB(177) = 30/255.0
          CNAME(177) = 'CHOCOLATE'
          RR(178) = 178/255.0
          RG(178) = 34/255.0
          RB(178) = 34/255.0
          CNAME(178) = 'FIREBRICK'
          RR(179) = 165/255.0
          RG(179) = 42/255.0
          RB(179) = 42/255.0
          CNAME(179) = 'BROWN'
          RR(180) = 233/255.0
          RG(180) = 150/255.0
          RB(180) = 122/255.0
          CNAME(180) = 'DARK SALMON'
          RR(181) = 233/255.0
          RG(181) = 150/255.0
          RB(181) = 122/255.0
          CNAME(181) = 'DARKSALMON'
          RR(182) = 250/255.0
          RG(182) = 128/255.0
          RB(182) = 114/255.0
          CNAME(182) = 'SALMON'
          RR(183) = 255/255.0
          RG(183) = 160/255.0
          RB(183) = 122/255.0
          CNAME(183) = 'LIGHT SALMON'
          RR(184) = 255/255.0
          RG(184) = 160/255.0
          RB(184) = 122/255.0
          CNAME(184) = 'LIGHTSALMON'
          RR(185) = 255/255.0
          RG(185) = 165/255.0
          RB(185) = 0/255.0
          CNAME(185) = 'ORANGE'
          RR(186) = 255/255.0
          RG(186) = 140/255.0
          RB(186) = 0/255.0
          CNAME(186) = 'DARK ORANGE'
          RR(187) = 255/255.0
          RG(187) = 140/255.0
          RB(187) = 0/255.0
          CNAME(187) = 'DARKORANGE'
          RR(188) = 255/255.0
          RG(188) = 127/255.0
          RB(188) = 80/255.0
          CNAME(188) = 'CORAL'
          RR(189) = 240/255.0
          RG(189) = 128/255.0
          RB(189) = 128/255.0
          CNAME(189) = 'LIGHT CORAL'
          RR(190) = 240/255.0
          RG(190) = 128/255.0
          RB(190) = 128/255.0
          CNAME(190) = 'LIGHTCORAL'
          RR(191) = 255/255.0
          RG(191) = 99/255.0
          RB(191) = 71/255.0
          CNAME(191) = 'TOMATO'
          RR(192) = 255/255.0
          RG(192) = 69/255.0
          RB(192) = 0/255.0
          CNAME(192) = 'ORANGE RED'
          RR(193) = 255/255.0
          RG(193) = 69/255.0
          RB(193) = 0/255.0
          CNAME(193) = 'ORANGERED'
          RR(194) = 255/255.0
          RG(194) = 0/255.0
          RB(194) = 0/255.0
          CNAME(194) = 'RED'
          RR(195) = 255/255.0
          RG(195) = 105/255.0
          RB(195) = 180/255.0
          CNAME(195) = 'HOT PINK'
          RR(196) = 255/255.0
          RG(196) = 105/255.0
          RB(196) = 180/255.0
          CNAME(196) = 'HOTPINK'
          RR(197) = 255/255.0
          RG(197) = 20/255.0
          RB(197) = 147/255.0
          CNAME(197) = 'DEEP PINK'
          RR(198) = 255/255.0
          RG(198) = 20/255.0
          RB(198) = 147/255.0
          CNAME(198) = 'DEEPPINK'
          RR(199) = 255/255.0
          RG(199) = 192/255.0
          RB(199) = 203/255.0
          CNAME(199) = 'PINK'
          RR(200) = 255/255.0
          RG(200) = 182/255.0
          RB(200) = 193/255.0
          CNAME(200) = 'LIGHT PINK'
          RR(201) = 255/255.0
          RG(201) = 182/255.0
          RB(201) = 193/255.0
          CNAME(201) = 'LIGHTPINK'
          RR(202) = 219/255.0
          RG(202) = 112/255.0
          RB(202) = 147/255.0
          CNAME(202) = 'PALE VIOLET RED'
          RR(203) = 219/255.0
          RG(203) = 112/255.0
          RB(203) = 147/255.0
          CNAME(203) = 'PALEVIOLETRED'
          RR(204) = 176/255.0
          RG(204) = 48/255.0
          RB(204) = 96/255.0
          CNAME(204) = 'MAROON'
          RR(205) = 199/255.0
          RG(205) = 21/255.0
          RB(205) = 133/255.0
          CNAME(205) = 'MEDIUM VIOLET RED'
          RR(206) = 199/255.0
          RG(206) = 21/255.0
          RB(206) = 133/255.0
          CNAME(206) = 'MEDIUMVIOLETRED'
          RR(207) = 208/255.0
          RG(207) = 32/255.0
          RB(207) = 144/255.0
          CNAME(207) = 'VIOLET RED'
          RR(208) = 208/255.0
          RG(208) = 32/255.0
          RB(208) = 144/255.0
          CNAME(208) = 'VIOLETRED'
          RR(209) = 255/255.0
          RG(209) = 0/255.0
          RB(209) = 255/255.0
          CNAME(209) = 'MAGENTA'
          RR(210) = 238/255.0
          RG(210) = 130/255.0
          RB(210) = 238/255.0
          CNAME(210) = 'VIOLET'
          RR(211) = 221/255.0
          RG(211) = 160/255.0
          RB(211) = 221/255.0
          CNAME(211) = 'PLUM'
          RR(212) = 218/255.0
          RG(212) = 112/255.0
          RB(212) = 214/255.0
          CNAME(212) = 'ORCHID'
          RR(213) = 186/255.0
          RG(213) = 85/255.0
          RB(213) = 211/255.0
          CNAME(213) = 'MEDIUM ORCHID'
          RR(214) = 186/255.0
          RG(214) = 85/255.0
          RB(214) = 211/255.0
          CNAME(214) = 'MEDIUMORCHID'
          RR(215) = 153/255.0
          RG(215) = 50/255.0
          RB(215) = 204/255.0
          CNAME(215) = 'DARK ORCHID'
          RR(216) = 153/255.0
          RG(216) = 50/255.0
          RB(216) = 204/255.0
          CNAME(216) = 'DARKORCHID'
          RR(217) = 148/255.0
          RG(217) = 0/255.0
          RB(217) = 211/255.0
          CNAME(217) = 'DARK VIOLET'
          RR(218) = 148/255.0
          RG(218) = 0/255.0
          RB(218) = 211/255.0
          CNAME(218) = 'DARKVIOLET'
          RR(219) = 138/255.0
          RG(219) = 43/255.0
          RB(219) = 226/255.0
          CNAME(219) = 'BLUE VIOLET'
          RR(220) = 138/255.0
          RG(220) = 43/255.0
          RB(220) = 226/255.0
          CNAME(220) = 'BLUEVIOLET'
          RR(221) = 160/255.0
          RG(221) = 32/255.0
          RB(221) = 240/255.0
          CNAME(221) = 'PURPLE'
          RR(222) = 147/255.0
          RG(222) = 112/255.0
          RB(222) = 219/255.0
          CNAME(222) = 'MEDIUM PURPLE'
          RR(223) = 147/255.0
          RG(223) = 112/255.0
          RB(223) = 219/255.0
          CNAME(223) = 'MEDIUMPURPLE'
          RR(224) = 216/255.0
          RG(224) = 191/255.0
          RB(224) = 216/255.0
          CNAME(224) = 'THISTLE'
          RR(225) = 255/255.0
          RG(225) = 250/255.0
          RB(225) = 250/255.0
          CNAME(225) = 'SNOW1'
          RR(226) = 238/255.0
          RG(226) = 233/255.0
          RB(226) = 233/255.0
          CNAME(226) = 'SNOW2'
          RR(227) = 205/255.0
          RG(227) = 201/255.0
          RB(227) = 201/255.0
          CNAME(227) = 'SNOW3'
          RR(228) = 139/255.0
          RG(228) = 137/255.0
          RB(228) = 137/255.0
          CNAME(228) = 'SNOW4'
          RR(229) = 255/255.0
          RG(229) = 245/255.0
          RB(229) = 238/255.0
          CNAME(229) = 'SEASHELL1'
          RR(230) = 238/255.0
          RG(230) = 229/255.0
          RB(230) = 222/255.0
          CNAME(230) = 'SEASHELL2'
          RR(231) = 205/255.0
          RG(231) = 197/255.0
          RB(231) = 191/255.0
          CNAME(231) = 'SEASHELL3'
          RR(232) = 139/255.0
          RG(232) = 134/255.0
          RB(232) = 130/255.0
          CNAME(232) = 'SEASHELL4'
          RR(233) = 255/255.0
          RG(233) = 239/255.0
          RB(233) = 219/255.0
          CNAME(233) = 'ANTIQUEWHITE1'
          RR(234) = 238/255.0
          RG(234) = 223/255.0
          RB(234) = 204/255.0
          CNAME(234) = 'ANTIQUEWHITE2'
          RR(235) = 205/255.0
          RG(235) = 192/255.0
          RB(235) = 176/255.0
          CNAME(235) = 'ANTIQUEWHITE3'
          RR(236) = 139/255.0
          RG(236) = 131/255.0
          RB(236) = 120/255.0
          CNAME(236) = 'ANTIQUEWHITE4'
          RR(237) = 255/255.0
          RG(237) = 228/255.0
          RB(237) = 196/255.0
          CNAME(237) = 'BISQUE1'
          RR(238) = 238/255.0
          RG(238) = 213/255.0
          RB(238) = 183/255.0
          CNAME(238) = 'BISQUE2'
          RR(239) = 205/255.0
          RG(239) = 183/255.0
          RB(239) = 158/255.0
          CNAME(239) = 'BISQUE3'
          RR(240) = 139/255.0
          RG(240) = 125/255.0
          RB(240) = 107/255.0
          CNAME(240) = 'BISQUE4'
          RR(241) = 255/255.0
          RG(241) = 218/255.0
          RB(241) = 185/255.0
          CNAME(241) = 'PEACHPUFF1'
          RR(242) = 238/255.0
          RG(242) = 203/255.0
          RB(242) = 173/255.0
          CNAME(242) = 'PEACHPUFF2'
          RR(243) = 205/255.0
          RG(243) = 175/255.0
          RB(243) = 149/255.0
          CNAME(243) = 'PEACHPUFF3'
          RR(244) = 139/255.0
          RG(244) = 119/255.0
          RB(244) = 101/255.0
          CNAME(244) = 'PEACHPUFF4'
          RR(245) = 255/255.0
          RG(245) = 222/255.0
          RB(245) = 173/255.0
          CNAME(245) = 'NAVAJOWHITE1'
          RR(246) = 238/255.0
          RG(246) = 207/255.0
          RB(246) = 161/255.0
          CNAME(246) = 'NAVAJOWHITE2'
          RR(247) = 205/255.0
          RG(247) = 179/255.0
          RB(247) = 139/255.0
          CNAME(247) = 'NAVAJOWHITE3'
          RR(248) = 139/255.0
          RG(248) = 121/255.0
          RB(248) = 94/255.0
          CNAME(248) = 'NAVAJOWHITE4'
          RR(249) = 255/255.0
          RG(249) = 250/255.0
          RB(249) = 205/255.0
          CNAME(249) = 'LEMONCHIFFON1'
          RR(250) = 238/255.0
          RG(250) = 233/255.0
          RB(250) = 191/255.0
          CNAME(250) = 'LEMONCHIFFON2'
          RR(251) = 205/255.0
          RG(251) = 201/255.0
          RB(251) = 165/255.0
          CNAME(251) = 'LEMONCHIFFON3'
          RR(252) = 139/255.0
          RG(252) = 137/255.0
          RB(252) = 112/255.0
          CNAME(252) = 'LEMONCHIFFON4'
          RR(253) = 255/255.0
          RG(253) = 248/255.0
          RB(253) = 220/255.0
          CNAME(253) = 'CORNSILK1'
          RR(254) = 238/255.0
          RG(254) = 232/255.0
          RB(254) = 205/255.0
          CNAME(254) = 'CORNSILK2'
          RR(255) = 205/255.0
          RG(255) = 200/255.0
          RB(255) = 177/255.0
          CNAME(255) = 'CORNSILK3'
          RR(256) = 139/255.0
          RG(256) = 136/255.0
          RB(256) = 120/255.0
          CNAME(256) = 'CORNSILK4'
          RR(257) = 255/255.0
          RG(257) = 255/255.0
          RB(257) = 240/255.0
          CNAME(257) = 'IVORY1'
          RR(258) = 238/255.0
          RG(258) = 238/255.0
          RB(258) = 224/255.0
          CNAME(258) = 'IVORY2'
          RR(259) = 205/255.0
          RG(259) = 205/255.0
          RB(259) = 193/255.0
          CNAME(259) = 'IVORY3'
          RR(260) = 139/255.0
          RG(260) = 139/255.0
          RB(260) = 131/255.0
          CNAME(260) = 'IVORY4'
          RR(261) = 240/255.0
          RG(261) = 255/255.0
          RB(261) = 240/255.0
          CNAME(261) = 'HONEYDEW1'
          RR(262) = 224/255.0
          RG(262) = 238/255.0
          RB(262) = 224/255.0
          CNAME(262) = 'HONEYDEW2'
          RR(263) = 193/255.0
          RG(263) = 205/255.0
          RB(263) = 193/255.0
          CNAME(263) = 'HONEYDEW3'
          RR(264) = 131/255.0
          RG(264) = 139/255.0
          RB(264) = 131/255.0
          CNAME(264) = 'HONEYDEW4'
          RR(265) = 255/255.0
          RG(265) = 240/255.0
          RB(265) = 245/255.0
          CNAME(265) = 'LAVENDERBLUSH1'
          RR(266) = 238/255.0
          RG(266) = 224/255.0
          RB(266) = 229/255.0
          CNAME(266) = 'LAVENDERBLUSH2'
          RR(267) = 205/255.0
          RG(267) = 193/255.0
          RB(267) = 197/255.0
          CNAME(267) = 'LAVENDERBLUSH3'
          RR(268) = 139/255.0
          RG(268) = 131/255.0
          RB(268) = 134/255.0
          CNAME(268) = 'LAVENDERBLUSH4'
          RR(269) = 255/255.0
          RG(269) = 228/255.0
          RB(269) = 225/255.0
          CNAME(269) = 'MISTYROSE1'
          RR(270) = 238/255.0
          RG(270) = 213/255.0
          RB(270) = 210/255.0
          CNAME(270) = 'MISTYROSE2'
          RR(271) = 205/255.0
          RG(271) = 183/255.0
          RB(271) = 181/255.0
          CNAME(271) = 'MISTYROSE3'
          RR(272) = 139/255.0
          RG(272) = 125/255.0
          RB(272) = 123/255.0
          CNAME(272) = 'MISTYROSE4'
          RR(273) = 240/255.0
          RG(273) = 255/255.0
          RB(273) = 255/255.0
          CNAME(273) = 'AZURE1'
          RR(274) = 224/255.0
          RG(274) = 238/255.0
          RB(274) = 238/255.0
          CNAME(274) = 'AZURE2'
          RR(275) = 193/255.0
          RG(275) = 205/255.0
          RB(275) = 205/255.0
          CNAME(275) = 'AZURE3'
          RR(276) = 131/255.0
          RG(276) = 139/255.0
          RB(276) = 139/255.0
          CNAME(276) = 'AZURE4'
          RR(277) = 131/255.0
          RG(277) = 111/255.0
          RB(277) = 255/255.0
          CNAME(277) = 'SLATEBLUE1'
          RR(278) = 122/255.0
          RG(278) = 103/255.0
          RB(278) = 238/255.0
          CNAME(278) = 'SLATEBLUE2'
          RR(279) = 105/255.0
          RG(279) = 89/255.0
          RB(279) = 205/255.0
          CNAME(279) = 'SLATEBLUE3'
          RR(280) = 71/255.0
          RG(280) = 60/255.0
          RB(280) = 139/255.0
          CNAME(280) = 'SLATEBLUE4'
          RR(281) = 72/255.0
          RG(281) = 118/255.0
          RB(281) = 255/255.0
          CNAME(281) = 'ROYALBLUE1'
          RR(282) = 67/255.0
          RG(282) = 110/255.0
          RB(282) = 238/255.0
          CNAME(282) = 'ROYALBLUE2'
          RR(283) = 58/255.0
          RG(283) = 95/255.0
          RB(283) = 205/255.0
          CNAME(283) = 'ROYALBLUE3'
          RR(284) = 39/255.0
          RG(284) = 64/255.0
          RB(284) = 139/255.0
          CNAME(284) = 'ROYALBLUE4'
          RR(285) = 0/255.0
          RG(285) = 0/255.0
          RB(285) = 255/255.0
          CNAME(285) = 'BLUE1'
          RR(286) = 0/255.0
          RG(286) = 0/255.0
          RB(286) = 238/255.0
          CNAME(286) = 'BLUE2'
          RR(287) = 0/255.0
          RG(287) = 0/255.0
          RB(287) = 205/255.0
          CNAME(287) = 'BLUE3'
          RR(288) = 0/255.0
          RG(288) = 0/255.0
          RB(288) = 139/255.0
          CNAME(288) = 'BLUE4'
          RR(289) = 30/255.0
          RG(289) = 144/255.0
          RB(289) = 255/255.0
          CNAME(289) = 'DODGERBLUE1'
          RR(290) = 28/255.0
          RG(290) = 134/255.0
          RB(290) = 238/255.0
          CNAME(290) = 'DODGERBLUE2'
          RR(291) = 24/255.0
          RG(291) = 116/255.0
          RB(291) = 205/255.0
          CNAME(291) = 'DODGERBLUE3'
          RR(292) = 16/255.0
          RG(292) = 78/255.0
          RB(292) = 139/255.0
          CNAME(292) = 'DODGERBLUE4'
          RR(293) = 99/255.0
          RG(293) = 184/255.0
          RB(293) = 255/255.0
          CNAME(293) = 'STEELBLUE1'
          RR(294) = 92/255.0
          RG(294) = 172/255.0
          RB(294) = 238/255.0
          CNAME(294) = 'STEELBLUE2'
          RR(295) = 79/255.0
          RG(295) = 148/255.0
          RB(295) = 205/255.0
          CNAME(295) = 'STEELBLUE3'
          RR(296) = 54/255.0
          RG(296) = 100/255.0
          RB(296) = 139/255.0
          CNAME(296) = 'STEELBLUE4'
          RR(297) = 0/255.0
          RG(297) = 191/255.0
          RB(297) = 255/255.0
          CNAME(297) = 'DEEPSKYBLUE1'
          RR(298) = 0/255.0
          RG(298) = 178/255.0
          RB(298) = 238/255.0
          CNAME(298) = 'DEEPSKYBLUE2'
          RR(299) = 0/255.0
          RG(299) = 154/255.0
          RB(299) = 205/255.0
          CNAME(299) = 'DEEPSKYBLUE3'
          RR(300) = 0/255.0
          RG(300) = 104/255.0
          RB(300) = 139/255.0
          CNAME(300) = 'DEEPSKYBLUE4'
          RR(301) = 135/255.0
          RG(301) = 206/255.0
          RB(301) = 255/255.0
          CNAME(301) = 'SKYBLUE1'
          RR(302) = 126/255.0
          RG(302) = 192/255.0
          RB(302) = 238/255.0
          CNAME(302) = 'SKYBLUE2'
          RR(303) = 108/255.0
          RG(303) = 166/255.0
          RB(303) = 205/255.0
          CNAME(303) = 'SKYBLUE3'
          RR(304) = 74/255.0
          RG(304) = 112/255.0
          RB(304) = 139/255.0
          CNAME(304) = 'SKYBLUE4'
          RR(305) = 176/255.0
          RG(305) = 226/255.0
          RB(305) = 255/255.0
          CNAME(305) = 'LIGHTSKYBLUE1'
          RR(306) = 164/255.0
          RG(306) = 211/255.0
          RB(306) = 238/255.0
          CNAME(306) = 'LIGHTSKYBLUE2'
          RR(307) = 141/255.0
          RG(307) = 182/255.0
          RB(307) = 205/255.0
          CNAME(307) = 'LIGHTSKYBLUE3'
          RR(308) = 96/255.0
          RG(308) = 123/255.0
          RB(308) = 139/255.0
          CNAME(308) = 'LIGHTSKYBLUE4'
          RR(309) = 198/255.0
          RG(309) = 226/255.0
          RB(309) = 255/255.0
          CNAME(309) = 'SLATEGRAY1'
          RR(310) = 185/255.0
          RG(310) = 211/255.0
          RB(310) = 238/255.0
          CNAME(310) = 'SLATEGRAY2'
          RR(311) = 159/255.0
          RG(311) = 182/255.0
          RB(311) = 205/255.0
          CNAME(311) = 'SLATEGRAY3'
          RR(312) = 108/255.0
          RG(312) = 123/255.0
          RB(312) = 139/255.0
          CNAME(312) = 'SLATEGRAY4'
          RR(313) = 202/255.0
          RG(313) = 225/255.0
          RB(313) = 255/255.0
          CNAME(313) = 'LIGHTSTEELBLUE1'
          RR(314) = 188/255.0
          RG(314) = 210/255.0
          RB(314) = 238/255.0
          CNAME(314) = 'LIGHTSTEELBLUE2'
          RR(315) = 162/255.0
          RG(315) = 181/255.0
          RB(315) = 205/255.0
          CNAME(315) = 'LIGHTSTEELBLUE3'
          RR(316) = 110/255.0
          RG(316) = 123/255.0
          RB(316) = 139/255.0
          CNAME(316) = 'LIGHTSTEELBLUE4'
          RR(317) = 191/255.0
          RG(317) = 239/255.0
          RB(317) = 255/255.0
          CNAME(317) = 'LIGHTBLUE1'
          RR(318) = 178/255.0
          RG(318) = 223/255.0
          RB(318) = 238/255.0
          CNAME(318) = 'LIGHTBLUE2'
          RR(319) = 154/255.0
          RG(319) = 192/255.0
          RB(319) = 205/255.0
          CNAME(319) = 'LIGHTBLUE3'
          RR(320) = 104/255.0
          RG(320) = 131/255.0
          RB(320) = 139/255.0
          CNAME(320) = 'LIGHTBLUE4'
          RR(321) = 224/255.0
          RG(321) = 255/255.0
          RB(321) = 255/255.0
          CNAME(321) = 'LIGHTCYAN1'
          RR(322) = 209/255.0
          RG(322) = 238/255.0
          RB(322) = 238/255.0
          CNAME(322) = 'LIGHTCYAN2'
          RR(323) = 180/255.0
          RG(323) = 205/255.0
          RB(323) = 205/255.0
          CNAME(323) = 'LIGHTCYAN3'
          RR(324) = 122/255.0
          RG(324) = 139/255.0
          RB(324) = 139/255.0
          CNAME(324) = 'LIGHTCYAN4'
          RR(325) = 187/255.0
          RG(325) = 255/255.0
          RB(325) = 255/255.0
          CNAME(325) = 'PALETURQUOISE1'
          RR(326) = 174/255.0
          RG(326) = 238/255.0
          RB(326) = 238/255.0
          CNAME(326) = 'PALETURQUOISE2'
          RR(327) = 150/255.0
          RG(327) = 205/255.0
          RB(327) = 205/255.0
          CNAME(327) = 'PALETURQUOISE3'
          RR(328) = 102/255.0
          RG(328) = 139/255.0
          RB(328) = 139/255.0
          CNAME(328) = 'PALETURQUOISE4'
          RR(329) = 152/255.0
          RG(329) = 245/255.0
          RB(329) = 255/255.0
          CNAME(329) = 'CADETBLUE1'
          RR(330) = 142/255.0
          RG(330) = 229/255.0
          RB(330) = 238/255.0
          CNAME(330) = 'CADETBLUE2'
          RR(331) = 122/255.0
          RG(331) = 197/255.0
          RB(331) = 205/255.0
          CNAME(331) = 'CADETBLUE3'
          RR(332) = 83/255.0
          RG(332) = 134/255.0
          RB(332) = 139/255.0
          CNAME(332) = 'CADETBLUE4'
          RR(333) = 0/255.0
          RG(333) = 245/255.0
          RB(333) = 255/255.0
          CNAME(333) = 'TURQUOISE1'
          RR(334) = 0/255.0
          RG(334) = 229/255.0
          RB(334) = 238/255.0
          CNAME(334) = 'TURQUOISE2'
          RR(335) = 0/255.0
          RG(335) = 197/255.0
          RB(335) = 205/255.0
          CNAME(335) = 'TURQUOISE3'
          RR(336) = 0/255.0
          RG(336) = 134/255.0
          RB(336) = 139/255.0
          CNAME(336) = 'TURQUOISE4'
          RR(337) = 0/255.0
          RG(337) = 255/255.0
          RB(337) = 255/255.0
          CNAME(337) = 'CYAN1'
          RR(338) = 0/255.0
          RG(338) = 238/255.0
          RB(338) = 238/255.0
          CNAME(338) = 'CYAN2'
          RR(339) = 0/255.0
          RG(339) = 205/255.0
          RB(339) = 205/255.0
          CNAME(339) = 'CYAN3'
          RR(340) = 0/255.0
          RG(340) = 139/255.0
          RB(340) = 139/255.0
          CNAME(340) = 'CYAN4'
          RR(341) = 151/255.0
          RG(341) = 255/255.0
          RB(341) = 255/255.0
          CNAME(341) = 'DARKSLATEGRAY1'
          RR(342) = 141/255.0
          RG(342) = 238/255.0
          RB(342) = 238/255.0
          CNAME(342) = 'DARKSLATEGRAY2'
          RR(343) = 121/255.0
          RG(343) = 205/255.0
          RB(343) = 205/255.0
          CNAME(343) = 'DARKSLATEGRAY3'
          RR(344) = 82/255.0
          RG(344) = 139/255.0
          RB(344) = 139/255.0
          CNAME(344) = 'DARKSLATEGRAY4'
          RR(345) = 127/255.0
          RG(345) = 255/255.0
          RB(345) = 212/255.0
          CNAME(345) = 'AQUAMARINE1'
          RR(346) = 118/255.0
          RG(346) = 238/255.0
          RB(346) = 198/255.0
          CNAME(346) = 'AQUAMARINE2'
          RR(347) = 102/255.0
          RG(347) = 205/255.0
          RB(347) = 170/255.0
          CNAME(347) = 'AQUAMARINE3'
          RR(348) = 69/255.0
          RG(348) = 139/255.0
          RB(348) = 116/255.0
          CNAME(348) = 'AQUAMARINE4'
          RR(349) = 193/255.0
          RG(349) = 255/255.0
          RB(349) = 193/255.0
          CNAME(349) = 'DARKSEAGREEN1'
          RR(350) = 180/255.0
          RG(350) = 238/255.0
          RB(350) = 180/255.0
          CNAME(350) = 'DARKSEAGREEN2'
          RR(351) = 155/255.0
          RG(351) = 205/255.0
          RB(351) = 155/255.0
          CNAME(351) = 'DARKSEAGREEN3'
          RR(352) = 105/255.0
          RG(352) = 139/255.0
          RB(352) = 105/255.0
          CNAME(352) = 'DARKSEAGREEN4'
          RR(353) = 84/255.0
          RG(353) = 255/255.0
          RB(353) = 159/255.0
          CNAME(353) = 'SEAGREEN1'
          RR(354) = 78/255.0
          RG(354) = 238/255.0
          RB(354) = 148/255.0
          CNAME(354) = 'SEAGREEN2'
          RR(355) = 67/255.0
          RG(355) = 205/255.0
          RB(355) = 128/255.0
          CNAME(355) = 'SEAGREEN3'
          RR(356) = 46/255.0
          RG(356) = 139/255.0
          RB(356) = 87/255.0
          CNAME(356) = 'SEAGREEN4'
          RR(357) = 154/255.0
          RG(357) = 255/255.0
          RB(357) = 154/255.0
          CNAME(357) = 'PALEGREEN1'
          RR(358) = 144/255.0
          RG(358) = 238/255.0
          RB(358) = 144/255.0
          CNAME(358) = 'PALEGREEN2'
          RR(359) = 124/255.0
          RG(359) = 205/255.0
          RB(359) = 124/255.0
          CNAME(359) = 'PALEGREEN3'
          RR(360) = 84/255.0
          RG(360) = 139/255.0
          RB(360) = 84/255.0
          CNAME(360) = 'PALEGREEN4'
          RR(361) = 0/255.0
          RG(361) = 255/255.0
          RB(361) = 127/255.0
          CNAME(361) = 'SPRINGGREEN1'
          RR(362) = 0/255.0
          RG(362) = 238/255.0
          RB(362) = 118/255.0
          CNAME(362) = 'SPRINGGREEN2'
          RR(363) = 0/255.0
          RG(363) = 205/255.0
          RB(363) = 102/255.0
          CNAME(363) = 'SPRINGGREEN3'
          RR(364) = 0/255.0
          RG(364) = 139/255.0
          RB(364) = 69/255.0
          CNAME(364) = 'SPRINGGREEN4'
          RR(365) = 0/255.0
          RG(365) = 255/255.0
          RB(365) = 0/255.0
          CNAME(365) = 'GREEN1'
          RR(366) = 0/255.0
          RG(366) = 238/255.0
          RB(366) = 0/255.0
          CNAME(366) = 'GREEN2'
          RR(367) = 0/255.0
          RG(367) = 205/255.0
          RB(367) = 0/255.0
          CNAME(367) = 'GREEN3'
          RR(368) = 0/255.0
          RG(368) = 139/255.0
          RB(368) = 0/255.0
          CNAME(368) = 'GREEN4'
          RR(369) = 127/255.0
          RG(369) = 255/255.0
          RB(369) = 0/255.0
          CNAME(369) = 'CHARTREUSE1'
          RR(370) = 118/255.0
          RG(370) = 238/255.0
          RB(370) = 0/255.0
          CNAME(370) = 'CHARTREUSE2'
          RR(371) = 102/255.0
          RG(371) = 205/255.0
          RB(371) = 0/255.0
          CNAME(371) = 'CHARTREUSE3'
          RR(372) = 69/255.0
          RG(372) = 139/255.0
          RB(372) = 0/255.0
          CNAME(372) = 'CHARTREUSE4'
          RR(373) = 192/255.0
          RG(373) = 255/255.0
          RB(373) = 62/255.0
          CNAME(373) = 'OLIVEDRAB1'
          RR(374) = 179/255.0
          RG(374) = 238/255.0
          RB(374) = 58/255.0
          CNAME(374) = 'OLIVEDRAB2'
          RR(375) = 154/255.0
          RG(375) = 205/255.0
          RB(375) = 50/255.0
          CNAME(375) = 'OLIVEDRAB3'
          RR(376) = 105/255.0
          RG(376) = 139/255.0
          RB(376) = 34/255.0
          CNAME(376) = 'OLIVEDRAB4'
          RR(377) = 202/255.0
          RG(377) = 255/255.0
          RB(377) = 112/255.0
          CNAME(377) = 'DARKOLIVEGREEN1'
          RR(378) = 188/255.0
          RG(378) = 238/255.0
          RB(378) = 104/255.0
          CNAME(378) = 'DARKOLIVEGREEN2'
          RR(379) = 162/255.0
          RG(379) = 205/255.0
          RB(379) = 90/255.0
          CNAME(379) = 'DARKOLIVEGREEN3'
          RR(380) = 110/255.0
          RG(380) = 139/255.0
          RB(380) = 61/255.0
          CNAME(380) = 'DARKOLIVEGREEN4'
          RR(381) = 255/255.0
          RG(381) = 246/255.0
          RB(381) = 143/255.0
          CNAME(381) = 'KHAKI1'
          RR(382) = 238/255.0
          RG(382) = 230/255.0
          RB(382) = 133/255.0
          CNAME(382) = 'KHAKI2'
          RR(383) = 205/255.0
          RG(383) = 198/255.0
          RB(383) = 115/255.0
          CNAME(383) = 'KHAKI3'
          RR(384) = 139/255.0
          RG(384) = 134/255.0
          RB(384) = 78/255.0
          CNAME(384) = 'KHAKI4'
          RR(385) = 255/255.0
          RG(385) = 236/255.0
          RB(385) = 139/255.0
          CNAME(385) = 'LIGHTGOLDENROD1'
          RR(386) = 238/255.0
          RG(386) = 220/255.0
          RB(386) = 130/255.0
          CNAME(386) = 'LIGHTGOLDENROD2'
          RR(387) = 205/255.0
          RG(387) = 190/255.0
          RB(387) = 112/255.0
          CNAME(387) = 'LIGHTGOLDENROD3'
          RR(388) = 139/255.0
          RG(388) = 129/255.0
          RB(388) = 76/255.0
          CNAME(388) = 'LIGHTGOLDENROD4'
          RR(389) = 255/255.0
          RG(389) = 255/255.0
          RB(389) = 224/255.0
          CNAME(389) = 'LIGHTYELLOW1'
          RR(390) = 238/255.0
          RG(390) = 238/255.0
          RB(390) = 209/255.0
          CNAME(390) = 'LIGHTYELLOW2'
          RR(391) = 205/255.0
          RG(391) = 205/255.0
          RB(391) = 180/255.0
          CNAME(391) = 'LIGHTYELLOW3'
          RR(392) = 139/255.0
          RG(392) = 139/255.0
          RB(392) = 122/255.0
          CNAME(392) = 'LIGHTYELLOW4'
          RR(393) = 255/255.0
          RG(393) = 255/255.0
          RB(393) = 0/255.0
          CNAME(393) = 'YELLOW1'
          RR(394) = 238/255.0
          RG(394) = 238/255.0
          RB(394) = 0/255.0
          CNAME(394) = 'YELLOW2'
          RR(395) = 205/255.0
          RG(395) = 205/255.0
          RB(395) = 0/255.0
          CNAME(395) = 'YELLOW3'
          RR(396) = 139/255.0
          RG(396) = 139/255.0
          RB(396) = 0/255.0
          CNAME(396) = 'YELLOW4'
          RR(397) = 255/255.0
          RG(397) = 215/255.0
          RB(397) = 0/255.0
          CNAME(397) = 'GOLD1'
          RR(398) = 238/255.0
          RG(398) = 201/255.0
          RB(398) = 0/255.0
          CNAME(398) = 'GOLD2'
          RR(399) = 205/255.0
          RG(399) = 173/255.0
          RB(399) = 0/255.0
          CNAME(399) = 'GOLD3'
          RR(400) = 139/255.0
          RG(400) = 117/255.0
          RB(400) = 0/255.0
          CNAME(400) = 'GOLD4'
          RR(401) = 255/255.0
          RG(401) = 193/255.0
          RB(401) = 37/255.0
          CNAME(401) = 'GOLDENROD1'
          RR(402) = 238/255.0
          RG(402) = 180/255.0
          RB(402) = 34/255.0
          CNAME(402) = 'GOLDENROD2'
          RR(403) = 205/255.0
          RG(403) = 155/255.0
          RB(403) = 29/255.0
          CNAME(403) = 'GOLDENROD3'
          RR(404) = 139/255.0
          RG(404) = 105/255.0
          RB(404) = 20/255.0
          CNAME(404) = 'GOLDENROD4'
          RR(405) = 255/255.0
          RG(405) = 185/255.0
          RB(405) = 15/255.0
          CNAME(405) = 'DARKGOLDENROD1'
          RR(406) = 238/255.0
          RG(406) = 173/255.0
          RB(406) = 14/255.0
          CNAME(406) = 'DARKGOLDENROD2'
          RR(407) = 205/255.0
          RG(407) = 149/255.0
          RB(407) = 12/255.0
          CNAME(407) = 'DARKGOLDENROD3'
          RR(408) = 139/255.0
          RG(408) = 101/255.0
          RB(408) = 8/255.0
          CNAME(408) = 'DARKGOLDENROD4'
          RR(409) = 255/255.0
          RG(409) = 193/255.0
          RB(409) = 193/255.0
          CNAME(409) = 'ROSYBROWN1'
          RR(410) = 238/255.0
          RG(410) = 180/255.0
          RB(410) = 180/255.0
          CNAME(410) = 'ROSYBROWN2'
          RR(411) = 205/255.0
          RG(411) = 155/255.0
          RB(411) = 155/255.0
          CNAME(411) = 'ROSYBROWN3'
          RR(412) = 139/255.0
          RG(412) = 105/255.0
          RB(412) = 105/255.0
          CNAME(412) = 'ROSYBROWN4'
          RR(413) = 255/255.0
          RG(413) = 106/255.0
          RB(413) = 106/255.0
          CNAME(413) = 'INDIANRED1'
          RR(414) = 238/255.0
          RG(414) = 99/255.0
          RB(414) = 99/255.0
          CNAME(414) = 'INDIANRED2'
          RR(415) = 205/255.0
          RG(415) = 85/255.0
          RB(415) = 85/255.0
          CNAME(415) = 'INDIANRED3'
          RR(416) = 139/255.0
          RG(416) = 58/255.0
          RB(416) = 58/255.0
          CNAME(416) = 'INDIANRED4'
          RR(417) = 255/255.0
          RG(417) = 130/255.0
          RB(417) = 71/255.0
          CNAME(417) = 'SIENNA1'
          RR(418) = 238/255.0
          RG(418) = 121/255.0
          RB(418) = 66/255.0
          CNAME(418) = 'SIENNA2'
          RR(419) = 205/255.0
          RG(419) = 104/255.0
          RB(419) = 57/255.0
          CNAME(419) = 'SIENNA3'
          RR(420) = 139/255.0
          RG(420) = 71/255.0
          RB(420) = 38/255.0
          CNAME(420) = 'SIENNA4'
          RR(421) = 255/255.0
          RG(421) = 211/255.0
          RB(421) = 155/255.0
          CNAME(421) = 'BURLYWOOD1'
          RR(422) = 238/255.0
          RG(422) = 197/255.0
          RB(422) = 145/255.0
          CNAME(422) = 'BURLYWOOD2'
          RR(423) = 205/255.0
          RG(423) = 170/255.0
          RB(423) = 125/255.0
          CNAME(423) = 'BURLYWOOD3'
          RR(424) = 139/255.0
          RG(424) = 115/255.0
          RB(424) = 85/255.0
          CNAME(424) = 'BURLYWOOD4'
          RR(425) = 255/255.0
          RG(425) = 231/255.0
          RB(425) = 186/255.0
          CNAME(425) = 'WHEAT1'
          RR(426) = 238/255.0
          RG(426) = 216/255.0
          RB(426) = 174/255.0
          CNAME(426) = 'WHEAT2'
          RR(427) = 205/255.0
          RG(427) = 186/255.0
          RB(427) = 150/255.0
          CNAME(427) = 'WHEAT3'
          RR(428) = 139/255.0
          RG(428) = 126/255.0
          RB(428) = 102/255.0
          CNAME(428) = 'WHEAT4'
          RR(429) = 255/255.0
          RG(429) = 165/255.0
          RB(429) = 79/255.0
          CNAME(429) = 'TAN1'
          RR(430) = 238/255.0
          RG(430) = 154/255.0
          RB(430) = 73/255.0
          CNAME(430) = 'TAN2'
          RR(431) = 205/255.0
          RG(431) = 133/255.0
          RB(431) = 63/255.0
          CNAME(431) = 'TAN3'
          RR(432) = 139/255.0
          RG(432) = 90/255.0
          RB(432) = 43/255.0
          CNAME(432) = 'TAN4'
          RR(433) = 255/255.0
          RG(433) = 127/255.0
          RB(433) = 36/255.0
          CNAME(433) = 'CHOCOLATE1'
          RR(434) = 238/255.0
          RG(434) = 118/255.0
          RB(434) = 33/255.0
          CNAME(434) = 'CHOCOLATE2'
          RR(435) = 205/255.0
          RG(435) = 102/255.0
          RB(435) = 29/255.0
          CNAME(435) = 'CHOCOLATE3'
          RR(436) = 139/255.0
          RG(436) = 69/255.0
          RB(436) = 19/255.0
          CNAME(436) = 'CHOCOLATE4'
          RR(437) = 255/255.0
          RG(437) = 48/255.0
          RB(437) = 48/255.0
          CNAME(437) = 'FIREBRICK1'
          RR(438) = 238/255.0
          RG(438) = 44/255.0
          RB(438) = 44/255.0
          CNAME(438) = 'FIREBRICK2'
          RR(439) = 205/255.0
          RG(439) = 38/255.0
          RB(439) = 38/255.0
          CNAME(439) = 'FIREBRICK3'
          RR(440) = 139/255.0
          RG(440) = 26/255.0
          RB(440) = 26/255.0
          CNAME(440) = 'FIREBRICK4'
          RR(441) = 255/255.0
          RG(441) = 64/255.0
          RB(441) = 64/255.0
          CNAME(441) = 'BROWN1'
          RR(442) = 238/255.0
          RG(442) = 59/255.0
          RB(442) = 59/255.0
          CNAME(442) = 'BROWN2'
          RR(443) = 205/255.0
          RG(443) = 51/255.0
          RB(443) = 51/255.0
          CNAME(443) = 'BROWN3'
          RR(444) = 139/255.0
          RG(444) = 35/255.0
          RB(444) = 35/255.0
          CNAME(444) = 'BROWN4'
          RR(445) = 255/255.0
          RG(445) = 140/255.0
          RB(445) = 105/255.0
          CNAME(445) = 'SALMON1'
          RR(446) = 238/255.0
          RG(446) = 130/255.0
          RB(446) = 98/255.0
          CNAME(446) = 'SALMON2'
          RR(447) = 205/255.0
          RG(447) = 112/255.0
          RB(447) = 84/255.0
          CNAME(447) = 'SALMON3'
          RR(448) = 139/255.0
          RG(448) = 76/255.0
          RB(448) = 57/255.0
          CNAME(448) = 'SALMON4'
          RR(449) = 255/255.0
          RG(449) = 160/255.0
          RB(449) = 122/255.0
          CNAME(449) = 'LIGHTSALMON1'
          RR(450) = 238/255.0
          RG(450) = 149/255.0
          RB(450) = 114/255.0
          CNAME(450) = 'LIGHTSALMON2'
          RR(451) = 205/255.0
          RG(451) = 129/255.0
          RB(451) = 98/255.0
          CNAME(451) = 'LIGHTSALMON3'
          RR(452) = 139/255.0
          RG(452) = 87/255.0
          RB(452) = 66/255.0
          CNAME(452) = 'LIGHTSALMON4'
          RR(453) = 255/255.0
          RG(453) = 165/255.0
          RB(453) = 0/255.0
          CNAME(453) = 'ORANGE1'
          RR(454) = 238/255.0
          RG(454) = 154/255.0
          RB(454) = 0/255.0
          CNAME(454) = 'ORANGE2'
          RR(455) = 205/255.0
          RG(455) = 133/255.0
          RB(455) = 0/255.0
          CNAME(455) = 'ORANGE3'
          RR(456) = 139/255.0
          RG(456) = 90/255.0
          RB(456) = 0/255.0
          CNAME(456) = 'ORANGE4'
          RR(457) = 255/255.0
          RG(457) = 127/255.0
          RB(457) = 0/255.0
          CNAME(457) = 'DARKORANGE1'
          RR(458) = 238/255.0
          RG(458) = 118/255.0
          RB(458) = 0/255.0
          CNAME(458) = 'DARKORANGE2'
          RR(459) = 205/255.0
          RG(459) = 102/255.0
          RB(459) = 0/255.0
          CNAME(459) = 'DARKORANGE3'
          RR(460) = 139/255.0
          RG(460) = 69/255.0
          RB(460) = 0/255.0
          CNAME(460) = 'DARKORANGE4'
          RR(461) = 255/255.0
          RG(461) = 114/255.0
          RB(461) = 86/255.0
          CNAME(461) = 'CORAL1'
          RR(462) = 238/255.0
          RG(462) = 106/255.0
          RB(462) = 80/255.0
          CNAME(462) = 'CORAL2'
          RR(463) = 205/255.0
          RG(463) = 91/255.0
          RB(463) = 69/255.0
          CNAME(463) = 'CORAL3'
          RR(464) = 139/255.0
          RG(464) = 62/255.0
          RB(464) = 47/255.0
          CNAME(464) = 'CORAL4'
          RR(465) = 255/255.0
          RG(465) = 99/255.0
          RB(465) = 71/255.0
          CNAME(465) = 'TOMATO1'
          RR(466) = 238/255.0
          RG(466) = 92/255.0
          RB(466) = 66/255.0
          CNAME(466) = 'TOMATO2'
          RR(467) = 205/255.0
          RG(467) = 79/255.0
          RB(467) = 57/255.0
          CNAME(467) = 'TOMATO3'
          RR(468) = 139/255.0
          RG(468) = 54/255.0
          RB(468) = 38/255.0
          CNAME(468) = 'TOMATO4'
          RR(469) = 255/255.0
          RG(469) = 69/255.0
          RB(469) = 0/255.0
          CNAME(469) = 'ORANGERED1'
          RR(470) = 238/255.0
          RG(470) = 64/255.0
          RB(470) = 0/255.0
          CNAME(470) = 'ORANGERED2'
          RR(471) = 205/255.0
          RG(471) = 55/255.0
          RB(471) = 0/255.0
          CNAME(471) = 'ORANGERED3'
          RR(472) = 139/255.0
          RG(472) = 37/255.0
          RB(472) = 0/255.0
          CNAME(472) = 'ORANGERED4'
          RR(473) = 255/255.0
          RG(473) = 0/255.0
          RB(473) = 0/255.0
          CNAME(473) = 'RED1'
          RR(474) = 238/255.0
          RG(474) = 0/255.0
          RB(474) = 0/255.0
          CNAME(474) = 'RED2'
          RR(475) = 205/255.0
          RG(475) = 0/255.0
          RB(475) = 0/255.0
          CNAME(475) = 'RED3'
          RR(476) = 139/255.0
          RG(476) = 0/255.0
          RB(476) = 0/255.0
          CNAME(476) = 'RED4'
          RR(477) = 255/255.0
          RG(477) = 20/255.0
          RB(477) = 147/255.0
          CNAME(477) = 'DEEPPINK1'
          RR(478) = 238/255.0
          RG(478) = 18/255.0
          RB(478) = 137/255.0
          CNAME(478) = 'DEEPPINK2'
          RR(479) = 205/255.0
          RG(479) = 16/255.0
          RB(479) = 118/255.0
          CNAME(479) = 'DEEPPINK3'
          RR(480) = 139/255.0
          RG(480) = 10/255.0
          RB(480) = 80/255.0
          CNAME(480) = 'DEEPPINK4'
          RR(481) = 255/255.0
          RG(481) = 110/255.0
          RB(481) = 180/255.0
          CNAME(481) = 'HOTPINK1'
          RR(482) = 238/255.0
          RG(482) = 106/255.0
          RB(482) = 167/255.0
          CNAME(482) = 'HOTPINK2'
          RR(483) = 205/255.0
          RG(483) = 96/255.0
          RB(483) = 144/255.0
          CNAME(483) = 'HOTPINK3'
          RR(484) = 139/255.0
          RG(484) = 58/255.0
          RB(484) = 98/255.0
          CNAME(484) = 'HOTPINK4'
          RR(485) = 255/255.0
          RG(485) = 181/255.0
          RB(485) = 197/255.0
          CNAME(485) = 'PINK1'
          RR(486) = 238/255.0
          RG(486) = 169/255.0
          RB(486) = 184/255.0
          CNAME(486) = 'PINK2'
          RR(487) = 205/255.0
          RG(487) = 145/255.0
          RB(487) = 158/255.0
          CNAME(487) = 'PINK3'
          RR(488) = 139/255.0
          RG(488) = 99/255.0
          RB(488) = 108/255.0
          CNAME(488) = 'PINK4'
          RR(489) = 255/255.0
          RG(489) = 174/255.0
          RB(489) = 185/255.0
          CNAME(489) = 'LIGHTPINK1'
          RR(490) = 238/255.0
          RG(490) = 162/255.0
          RB(490) = 173/255.0
          CNAME(490) = 'LIGHTPINK2'
          RR(491) = 205/255.0
          RG(491) = 140/255.0
          RB(491) = 149/255.0
          CNAME(491) = 'LIGHTPINK3'
          RR(492) = 139/255.0
          RG(492) = 95/255.0
          RB(492) = 101/255.0
          CNAME(492) = 'LIGHTPINK4'
          RR(493) = 255/255.0
          RG(493) = 130/255.0
          RB(493) = 171/255.0
          CNAME(493) = 'PALEVIOLETRED1'
          RR(494) = 238/255.0
          RG(494) = 121/255.0
          RB(494) = 159/255.0
          CNAME(494) = 'PALEVIOLETRED2'
          RR(495) = 205/255.0
          RG(495) = 104/255.0
          RB(495) = 137/255.0
          CNAME(495) = 'PALEVIOLETRED3'
          RR(496) = 139/255.0
          RG(496) = 71/255.0
          RB(496) = 93/255.0
          CNAME(496) = 'PALEVIOLETRED4'
          RR(497) = 255/255.0
          RG(497) = 52/255.0
          RB(497) = 179/255.0
          CNAME(497) = 'MAROON1'
          RR(498) = 238/255.0
          RG(498) = 48/255.0
          RB(498) = 167/255.0
          CNAME(498) = 'MAROON2'
          RR(499) = 205/255.0
          RG(499) = 41/255.0
          RB(499) = 144/255.0
          CNAME(499) = 'MAROON3'
          RR(500) = 139/255.0
          RG(500) = 28/255.0
          RB(500) = 98/255.0
          CNAME(500) = 'MAROON4'
          RR(501) = 255/255.0
          RG(501) = 62/255.0
          RB(501) = 150/255.0
          CNAME(501) = 'VIOLETRED1'
          RR(502) = 238/255.0
          RG(502) = 58/255.0
          RB(502) = 140/255.0
          CNAME(502) = 'VIOLETRED2'
          RR(503) = 205/255.0
          RG(503) = 50/255.0
          RB(503) = 120/255.0
          CNAME(503) = 'VIOLETRED3'
          RR(504) = 139/255.0
          RG(504) = 34/255.0
          RB(504) = 82/255.0
          CNAME(504) = 'VIOLETRED4'
          RR(505) = 255/255.0
          RG(505) = 0/255.0
          RB(505) = 255/255.0
          CNAME(505) = 'MAGENTA1'
          RR(506) = 238/255.0
          RG(506) = 0/255.0
          RB(506) = 238/255.0
          CNAME(506) = 'MAGENTA2'
          RR(507) = 205/255.0
          RG(507) = 0/255.0
          RB(507) = 205/255.0
          CNAME(507) = 'MAGENTA3'
          RR(508) = 139/255.0
          RG(508) = 0/255.0
          RB(508) = 139/255.0
          CNAME(508) = 'MAGENTA4'
          RR(509) = 255/255.0
          RG(509) = 131/255.0
          RB(509) = 250/255.0
          CNAME(509) = 'ORCHID1'
          RR(510) = 238/255.0
          RG(510) = 122/255.0
          RB(510) = 233/255.0
          CNAME(510) = 'ORCHID2'
          RR(511) = 205/255.0
          RG(511) = 105/255.0
          RB(511) = 201/255.0
          CNAME(511) = 'ORCHID3'
          RR(512) = 139/255.0
          RG(512) = 71/255.0
          RB(512) = 137/255.0
          CNAME(512) = 'ORCHID4'
          RR(513) = 255/255.0
          RG(513) = 187/255.0
          RB(513) = 255/255.0
          CNAME(513) = 'PLUM1'
          RR(514) = 238/255.0
          RG(514) = 174/255.0
          RB(514) = 238/255.0
          CNAME(514) = 'PLUM2'
          RR(515) = 205/255.0
          RG(515) = 150/255.0
          RB(515) = 205/255.0
          CNAME(515) = 'PLUM3'
          RR(516) = 139/255.0
          RG(516) = 102/255.0
          RB(516) = 139/255.0
          CNAME(516) = 'PLUM4'
          RR(517) = 224/255.0
          RG(517) = 102/255.0
          RB(517) = 255/255.0
          CNAME(517) = 'MEDIUMORCHID1'
          RR(518) = 209/255.0
          RG(518) = 95/255.0
          RB(518) = 238/255.0
          CNAME(518) = 'MEDIUMORCHID2'
          RR(519) = 180/255.0
          RG(519) = 82/255.0
          RB(519) = 205/255.0
          CNAME(519) = 'MEDIUMORCHID3'
          RR(520) = 122/255.0
          RG(520) = 55/255.0
          RB(520) = 139/255.0
          CNAME(520) = 'MEDIUMORCHID4'
          RR(521) = 191/255.0
          RG(521) = 62/255.0
          RB(521) = 255/255.0
          CNAME(521) = 'DARKORCHID1'
          RR(522) = 178/255.0
          RG(522) = 58/255.0
          RB(522) = 238/255.0
          CNAME(522) = 'DARKORCHID2'
          RR(523) = 154/255.0
          RG(523) = 50/255.0
          RB(523) = 205/255.0
          CNAME(523) = 'DARKORCHID3'
          RR(524) = 104/255.0
          RG(524) = 34/255.0
          RB(524) = 139/255.0
          CNAME(524) = 'DARKORCHID4'
          RR(525) = 155/255.0
          RG(525) = 48/255.0
          RB(525) = 255/255.0
          CNAME(525) = 'PURPLE1'
          RR(526) = 145/255.0
          RG(526) = 44/255.0
          RB(526) = 238/255.0
          CNAME(526) = 'PURPLE2'
          RR(527) = 125/255.0
          RG(527) = 38/255.0
          RB(527) = 205/255.0
          CNAME(527) = 'PURPLE3'
          RR(528) = 85/255.0
          RG(528) = 26/255.0
          RB(528) = 139/255.0
          CNAME(528) = 'PURPLE4'
          RR(529) = 171/255.0
          RG(529) = 130/255.0
          RB(529) = 255/255.0
          CNAME(529) = 'MEDIUMPURPLE1'
          RR(530) = 159/255.0
          RG(530) = 121/255.0
          RB(530) = 238/255.0
          CNAME(530) = 'MEDIUMPURPLE2'
          RR(531) = 137/255.0
          RG(531) = 104/255.0
          RB(531) = 205/255.0
          CNAME(531) = 'MEDIUMPURPLE3'
          RR(532) = 93/255.0
          RG(532) = 71/255.0
          RB(532) = 139/255.0
          CNAME(532) = 'MEDIUMPURPLE4'
          RR(533) = 255/255.0
          RG(533) = 225/255.0
          RB(533) = 255/255.0
          CNAME(533) = 'THISTLE1'
          RR(534) = 238/255.0
          RG(534) = 210/255.0
          RB(534) = 238/255.0
          CNAME(534) = 'THISTLE2'
          RR(535) = 205/255.0
          RG(535) = 181/255.0
          RB(535) = 205/255.0
          CNAME(535) = 'THISTLE3'
          RR(536) = 139/255.0
          RG(536) = 123/255.0
          RB(536) = 139/255.0
          CNAME(536) = 'THISTLE4'
          RR(537) = 0/255.0
          RG(537) = 0/255.0
          RB(537) = 0/255.0
          CNAME(537) = 'GRAY0'
          RR(538) = 0/255.0
          RG(538) = 0/255.0
          RB(538) = 0/255.0
          CNAME(538) = 'GREY0'
          RR(539) = 3/255.0
          RG(539) = 3/255.0
          RB(539) = 3/255.0
          CNAME(539) = 'GRAY1'
          RR(540) = 3/255.0
          RG(540) = 3/255.0
          RB(540) = 3/255.0
          CNAME(540) = 'GREY1'
          RR(541) = 5/255.0
          RG(541) = 5/255.0
          RB(541) = 5/255.0
          CNAME(541) = 'GRAY2'
          RR(542) = 5/255.0
          RG(542) = 5/255.0
          RB(542) = 5/255.0
          CNAME(542) = 'GREY2'
          RR(543) = 8/255.0
          RG(543) = 8/255.0
          RB(543) = 8/255.0
          CNAME(543) = 'GRAY3'
          RR(544) = 8/255.0
          RG(544) = 8/255.0
          RB(544) = 8/255.0
          CNAME(544) = 'GREY3'
          RR(545) = 10/255.0
          RG(545) = 10/255.0
          RB(545) = 10/255.0
          CNAME(545) = 'GRAY4'
          RR(546) = 10/255.0
          RG(546) = 10/255.0
          RB(546) = 10/255.0
          CNAME(546) = 'GREY4'
          RR(547) = 13/255.0
          RG(547) = 13/255.0
          RB(547) = 13/255.0
          CNAME(547) = 'GRAY5'
          RR(548) = 13/255.0
          RG(548) = 13/255.0
          RB(548) = 13/255.0
          CNAME(548) = 'GREY5'
          RR(549) = 15/255.0
          RG(549) = 15/255.0
          RB(549) = 15/255.0
          CNAME(549) = 'GRAY6'
          RR(550) = 15/255.0
          RG(550) = 15/255.0
          RB(550) = 15/255.0
          CNAME(550) = 'GREY6'
          RR(551) = 18/255.0
          RG(551) = 18/255.0
          RB(551) = 18/255.0
          CNAME(551) = 'GRAY7'
          RR(552) = 18/255.0
          RG(552) = 18/255.0
          RB(552) = 18/255.0
          CNAME(552) = 'GREY7'
          RR(553) = 20/255.0
          RG(553) = 20/255.0
          RB(553) = 20/255.0
          CNAME(553) = 'GRAY8'
          RR(554) = 20/255.0
          RG(554) = 20/255.0
          RB(554) = 20/255.0
          CNAME(554) = 'GREY8'
          RR(555) = 23/255.0
          RG(555) = 23/255.0
          RB(555) = 23/255.0
          CNAME(555) = 'GRAY9'
          RR(556) = 23/255.0
          RG(556) = 23/255.0
          RB(556) = 23/255.0
          CNAME(556) = 'GREY9'
          RR(557) = 26/255.0
          RG(557) = 26/255.0
          RB(557) = 26/255.0
          CNAME(557) = 'GRAY10'
          RR(558) = 26/255.0
          RG(558) = 26/255.0
          RB(558) = 26/255.0
          CNAME(558) = 'GREY10'
          RR(559) = 28/255.0
          RG(559) = 28/255.0
          RB(559) = 28/255.0
          CNAME(559) = 'GRAY11'
          RR(560) = 28/255.0
          RG(560) = 28/255.0
          RB(560) = 28/255.0
          CNAME(560) = 'GREY11'
          RR(561) = 31/255.0
          RG(561) = 31/255.0
          RB(561) = 31/255.0
          CNAME(561) = 'GRAY12'
          RR(562) = 31/255.0
          RG(562) = 31/255.0
          RB(562) = 31/255.0
          CNAME(562) = 'GREY12'
          RR(563) = 33/255.0
          RG(563) = 33/255.0
          RB(563) = 33/255.0
          CNAME(563) = 'GRAY13'
          RR(564) = 33/255.0
          RG(564) = 33/255.0
          RB(564) = 33/255.0
          CNAME(564) = 'GREY13'
          RR(565) = 36/255.0
          RG(565) = 36/255.0
          RB(565) = 36/255.0
          CNAME(565) = 'GRAY14'
          RR(566) = 36/255.0
          RG(566) = 36/255.0
          RB(566) = 36/255.0
          CNAME(566) = 'GREY14'
          RR(567) = 38/255.0
          RG(567) = 38/255.0
          RB(567) = 38/255.0
          CNAME(567) = 'GRAY15'
          RR(568) = 38/255.0
          RG(568) = 38/255.0
          RB(568) = 38/255.0
          CNAME(568) = 'GREY15'
          RR(569) = 41/255.0
          RG(569) = 41/255.0
          RB(569) = 41/255.0
          CNAME(569) = 'GRAY16'
          RR(570) = 41/255.0
          RG(570) = 41/255.0
          RB(570) = 41/255.0
          CNAME(570) = 'GREY16'
          RR(571) = 43/255.0
          RG(571) = 43/255.0
          RB(571) = 43/255.0
          CNAME(571) = 'GRAY17'
          RR(572) = 43/255.0
          RG(572) = 43/255.0
          RB(572) = 43/255.0
          CNAME(572) = 'GREY17'
          RR(573) = 46/255.0
          RG(573) = 46/255.0
          RB(573) = 46/255.0
          CNAME(573) = 'GRAY18'
          RR(574) = 46/255.0
          RG(574) = 46/255.0
          RB(574) = 46/255.0
          CNAME(574) = 'GREY18'
          RR(575) = 48/255.0
          RG(575) = 48/255.0
          RB(575) = 48/255.0
          CNAME(575) = 'GRAY19'
          RR(576) = 48/255.0
          RG(576) = 48/255.0
          RB(576) = 48/255.0
          CNAME(576) = 'GREY19'
          RR(577) = 51/255.0
          RG(577) = 51/255.0
          RB(577) = 51/255.0
          CNAME(577) = 'GRAY20'
          RR(578) = 51/255.0
          RG(578) = 51/255.0
          RB(578) = 51/255.0
          CNAME(578) = 'GREY20'
          RR(579) = 54/255.0
          RG(579) = 54/255.0
          RB(579) = 54/255.0
          CNAME(579) = 'GRAY21'
          RR(580) = 54/255.0
          RG(580) = 54/255.0
          RB(580) = 54/255.0
          CNAME(580) = 'GREY21'
          RR(581) = 56/255.0
          RG(581) = 56/255.0
          RB(581) = 56/255.0
          CNAME(581) = 'GRAY22'
          RR(582) = 56/255.0
          RG(582) = 56/255.0
          RB(582) = 56/255.0
          CNAME(582) = 'GREY22'
          RR(583) = 59/255.0
          RG(583) = 59/255.0
          RB(583) = 59/255.0
          CNAME(583) = 'GRAY23'
          RR(584) = 59/255.0
          RG(584) = 59/255.0
          RB(584) = 59/255.0
          CNAME(584) = 'GREY23'
          RR(585) = 61/255.0
          RG(585) = 61/255.0
          RB(585) = 61/255.0
          CNAME(585) = 'GRAY24'
          RR(586) = 61/255.0
          RG(586) = 61/255.0
          RB(586) = 61/255.0
          CNAME(586) = 'GREY24'
          RR(587) = 64/255.0
          RG(587) = 64/255.0
          RB(587) = 64/255.0
          CNAME(587) = 'GRAY25'
          RR(588) = 64/255.0
          RG(588) = 64/255.0
          RB(588) = 64/255.0
          CNAME(588) = 'GREY25'
          RR(589) = 66/255.0
          RG(589) = 66/255.0
          RB(589) = 66/255.0
          CNAME(589) = 'GRAY26'
          RR(590) = 66/255.0
          RG(590) = 66/255.0
          RB(590) = 66/255.0
          CNAME(590) = 'GREY26'
          RR(591) = 69/255.0
          RG(591) = 69/255.0
          RB(591) = 69/255.0
          CNAME(591) = 'GRAY27'
          RR(592) = 69/255.0
          RG(592) = 69/255.0
          RB(592) = 69/255.0
          CNAME(592) = 'GREY27'
          RR(593) = 71/255.0
          RG(593) = 71/255.0
          RB(593) = 71/255.0
          CNAME(593) = 'GRAY28'
          RR(594) = 71/255.0
          RG(594) = 71/255.0
          RB(594) = 71/255.0
          CNAME(594) = 'GREY28'
          RR(595) = 74/255.0
          RG(595) = 74/255.0
          RB(595) = 74/255.0
          CNAME(595) = 'GRAY29'
          RR(596) = 74/255.0
          RG(596) = 74/255.0
          RB(596) = 74/255.0
          CNAME(596) = 'GREY29'
          RR(597) = 77/255.0
          RG(597) = 77/255.0
          RB(597) = 77/255.0
          CNAME(597) = 'GRAY30'
          RR(598) = 77/255.0
          RG(598) = 77/255.0
          RB(598) = 77/255.0
          CNAME(598) = 'GREY30'
          RR(599) = 79/255.0
          RG(599) = 79/255.0
          RB(599) = 79/255.0
          CNAME(599) = 'GRAY31'
          RR(600) = 79/255.0
          RG(600) = 79/255.0
          RB(600) = 79/255.0
          CNAME(600) = 'GREY31'
          RR(601) = 82/255.0
          RG(601) = 82/255.0
          RB(601) = 82/255.0
          CNAME(601) = 'GRAY32'
          RR(602) = 82/255.0
          RG(602) = 82/255.0
          RB(602) = 82/255.0
          CNAME(602) = 'GREY32'
          RR(603) = 84/255.0
          RG(603) = 84/255.0
          RB(603) = 84/255.0
          CNAME(603) = 'GRAY33'
          RR(604) = 84/255.0
          RG(604) = 84/255.0
          RB(604) = 84/255.0
          CNAME(604) = 'GREY33'
          RR(605) = 87/255.0
          RG(605) = 87/255.0
          RB(605) = 87/255.0
          CNAME(605) = 'GRAY34'
          RR(606) = 87/255.0
          RG(606) = 87/255.0
          RB(606) = 87/255.0
          CNAME(606) = 'GREY34'
          RR(607) = 89/255.0
          RG(607) = 89/255.0
          RB(607) = 89/255.0
          CNAME(607) = 'GRAY35'
          RR(608) = 89/255.0
          RG(608) = 89/255.0
          RB(608) = 89/255.0
          CNAME(608) = 'GREY35'
          RR(609) = 92/255.0
          RG(609) = 92/255.0
          RB(609) = 92/255.0
          CNAME(609) = 'GRAY36'
          RR(610) = 92/255.0
          RG(610) = 92/255.0
          RB(610) = 92/255.0
          CNAME(610) = 'GREY36'
          RR(611) = 94/255.0
          RG(611) = 94/255.0
          RB(611) = 94/255.0
          CNAME(611) = 'GRAY37'
          RR(612) = 94/255.0
          RG(612) = 94/255.0
          RB(612) = 94/255.0
          CNAME(612) = 'GREY37'
          RR(613) = 97/255.0
          RG(613) = 97/255.0
          RB(613) = 97/255.0
          CNAME(613) = 'GRAY38'
          RR(614) = 97/255.0
          RG(614) = 97/255.0
          RB(614) = 97/255.0
          CNAME(614) = 'GREY38'
          RR(615) = 99/255.0
          RG(615) = 99/255.0
          RB(615) = 99/255.0
          CNAME(615) = 'GRAY39'
          RR(616) = 99/255.0
          RG(616) = 99/255.0
          RB(616) = 99/255.0
          CNAME(616) = 'GREY39'
          RR(617) = 102/255.0
          RG(617) = 102/255.0
          RB(617) = 102/255.0
          CNAME(617) = 'GRAY40'
          RR(618) = 102/255.0
          RG(618) = 102/255.0
          RB(618) = 102/255.0
          CNAME(618) = 'GREY40'
          RR(619) = 105/255.0
          RG(619) = 105/255.0
          RB(619) = 105/255.0
          CNAME(619) = 'GRAY41'
          RR(620) = 105/255.0
          RG(620) = 105/255.0
          RB(620) = 105/255.0
          CNAME(620) = 'GREY41'
          RR(621) = 107/255.0
          RG(621) = 107/255.0
          RB(621) = 107/255.0
          CNAME(621) = 'GRAY42'
          RR(622) = 107/255.0
          RG(622) = 107/255.0
          RB(622) = 107/255.0
          CNAME(622) = 'GREY42'
          RR(623) = 110/255.0
          RG(623) = 110/255.0
          RB(623) = 110/255.0
          CNAME(623) = 'GRAY43'
          RR(624) = 110/255.0
          RG(624) = 110/255.0
          RB(624) = 110/255.0
          CNAME(624) = 'GREY43'
          RR(625) = 112/255.0
          RG(625) = 112/255.0
          RB(625) = 112/255.0
          CNAME(625) = 'GRAY44'
          RR(626) = 112/255.0
          RG(626) = 112/255.0
          RB(626) = 112/255.0
          CNAME(626) = 'GREY44'
          RR(627) = 115/255.0
          RG(627) = 115/255.0
          RB(627) = 115/255.0
          CNAME(627) = 'GRAY45'
          RR(628) = 115/255.0
          RG(628) = 115/255.0
          RB(628) = 115/255.0
          CNAME(628) = 'GREY45'
          RR(629) = 117/255.0
          RG(629) = 117/255.0
          RB(629) = 117/255.0
          CNAME(629) = 'GRAY46'
          RR(630) = 117/255.0
          RG(630) = 117/255.0
          RB(630) = 117/255.0
          CNAME(630) = 'GREY46'
          RR(631) = 120/255.0
          RG(631) = 120/255.0
          RB(631) = 120/255.0
          CNAME(631) = 'GRAY47'
          RR(632) = 120/255.0
          RG(632) = 120/255.0
          RB(632) = 120/255.0
          CNAME(632) = 'GREY47'
          RR(633) = 122/255.0
          RG(633) = 122/255.0
          RB(633) = 122/255.0
          CNAME(633) = 'GRAY48'
          RR(634) = 122/255.0
          RG(634) = 122/255.0
          RB(634) = 122/255.0
          CNAME(634) = 'GREY48'
          RR(635) = 125/255.0
          RG(635) = 125/255.0
          RB(635) = 125/255.0
          CNAME(635) = 'GRAY49'
          RR(636) = 125/255.0
          RG(636) = 125/255.0
          RB(636) = 125/255.0
          CNAME(636) = 'GREY49'
          RR(637) = 127/255.0
          RG(637) = 127/255.0
          RB(637) = 127/255.0
          CNAME(637) = 'GRAY50'
          RR(638) = 127/255.0
          RG(638) = 127/255.0
          RB(638) = 127/255.0
          CNAME(638) = 'GREY50'
          RR(639) = 130/255.0
          RG(639) = 130/255.0
          RB(639) = 130/255.0
          CNAME(639) = 'GRAY51'
          RR(640) = 130/255.0
          RG(640) = 130/255.0
          RB(640) = 130/255.0
          CNAME(640) = 'GREY51'
          RR(641) = 133/255.0
          RG(641) = 133/255.0
          RB(641) = 133/255.0
          CNAME(641) = 'GRAY52'
          RR(642) = 133/255.0
          RG(642) = 133/255.0
          RB(642) = 133/255.0
          CNAME(642) = 'GREY52'
          RR(643) = 135/255.0
          RG(643) = 135/255.0
          RB(643) = 135/255.0
          CNAME(643) = 'GRAY53'
          RR(644) = 135/255.0
          RG(644) = 135/255.0
          RB(644) = 135/255.0
          CNAME(644) = 'GREY53'
          RR(645) = 138/255.0
          RG(645) = 138/255.0
          RB(645) = 138/255.0
          CNAME(645) = 'GRAY54'
          RR(646) = 138/255.0
          RG(646) = 138/255.0
          RB(646) = 138/255.0
          CNAME(646) = 'GREY54'
          RR(647) = 140/255.0
          RG(647) = 140/255.0
          RB(647) = 140/255.0
          CNAME(647) = 'GRAY55'
          RR(648) = 140/255.0
          RG(648) = 140/255.0
          RB(648) = 140/255.0
          CNAME(648) = 'GREY55'
          RR(649) = 143/255.0
          RG(649) = 143/255.0
          RB(649) = 143/255.0
          CNAME(649) = 'GRAY56'
          RR(650) = 143/255.0
          RG(650) = 143/255.0
          RB(650) = 143/255.0
          CNAME(650) = 'GREY56'
          RR(651) = 145/255.0
          RG(651) = 145/255.0
          RB(651) = 145/255.0
          CNAME(651) = 'GRAY57'
          RR(652) = 145/255.0
          RG(652) = 145/255.0
          RB(652) = 145/255.0
          CNAME(652) = 'GREY57'
          RR(653) = 148/255.0
          RG(653) = 148/255.0
          RB(653) = 148/255.0
          CNAME(653) = 'GRAY58'
          RR(654) = 148/255.0
          RG(654) = 148/255.0
          RB(654) = 148/255.0
          CNAME(654) = 'GREY58'
          RR(655) = 150/255.0
          RG(655) = 150/255.0
          RB(655) = 150/255.0
          CNAME(655) = 'GRAY59'
          RR(656) = 150/255.0
          RG(656) = 150/255.0
          RB(656) = 150/255.0
          CNAME(656) = 'GREY59'
          RR(657) = 153/255.0
          RG(657) = 153/255.0
          RB(657) = 153/255.0
          CNAME(657) = 'GRAY60'
          RR(658) = 153/255.0
          RG(658) = 153/255.0
          RB(658) = 153/255.0
          CNAME(658) = 'GREY60'
          RR(659) = 156/255.0
          RG(659) = 156/255.0
          RB(659) = 156/255.0
          CNAME(659) = 'GRAY61'
          RR(660) = 156/255.0
          RG(660) = 156/255.0
          RB(660) = 156/255.0
          CNAME(660) = 'GREY61'
          RR(661) = 158/255.0
          RG(661) = 158/255.0
          RB(661) = 158/255.0
          CNAME(661) = 'GRAY62'
          RR(662) = 158/255.0
          RG(662) = 158/255.0
          RB(662) = 158/255.0
          CNAME(662) = 'GREY62'
          RR(663) = 161/255.0
          RG(663) = 161/255.0
          RB(663) = 161/255.0
          CNAME(663) = 'GRAY63'
          RR(664) = 161/255.0
          RG(664) = 161/255.0
          RB(664) = 161/255.0
          CNAME(664) = 'GREY63'
          RR(665) = 163/255.0
          RG(665) = 163/255.0
          RB(665) = 163/255.0
          CNAME(665) = 'GRAY64'
          RR(666) = 163/255.0
          RG(666) = 163/255.0
          RB(666) = 163/255.0
          CNAME(666) = 'GREY64'
          RR(667) = 166/255.0
          RG(667) = 166/255.0
          RB(667) = 166/255.0
          CNAME(667) = 'GRAY65'
          RR(668) = 166/255.0
          RG(668) = 166/255.0
          RB(668) = 166/255.0
          CNAME(668) = 'GREY65'
          RR(669) = 168/255.0
          RG(669) = 168/255.0
          RB(669) = 168/255.0
          CNAME(669) = 'GRAY66'
          RR(670) = 168/255.0
          RG(670) = 168/255.0
          RB(670) = 168/255.0
          CNAME(670) = 'GREY66'
          RR(671) = 171/255.0
          RG(671) = 171/255.0
          RB(671) = 171/255.0
          CNAME(671) = 'GRAY67'
          RR(672) = 171/255.0
          RG(672) = 171/255.0
          RB(672) = 171/255.0
          CNAME(672) = 'GREY67'
          RR(673) = 173/255.0
          RG(673) = 173/255.0
          RB(673) = 173/255.0
          CNAME(673) = 'GRAY68'
          RR(674) = 173/255.0
          RG(674) = 173/255.0
          RB(674) = 173/255.0
          CNAME(674) = 'GREY68'
          RR(675) = 176/255.0
          RG(675) = 176/255.0
          RB(675) = 176/255.0
          CNAME(675) = 'GRAY69'
          RR(676) = 176/255.0
          RG(676) = 176/255.0
          RB(676) = 176/255.0
          CNAME(676) = 'GREY69'
          RR(677) = 179/255.0
          RG(677) = 179/255.0
          RB(677) = 179/255.0
          CNAME(677) = 'GRAY70'
          RR(678) = 179/255.0
          RG(678) = 179/255.0
          RB(678) = 179/255.0
          CNAME(678) = 'GREY70'
          RR(679) = 181/255.0
          RG(679) = 181/255.0
          RB(679) = 181/255.0
          CNAME(679) = 'GRAY71'
          RR(680) = 181/255.0
          RG(680) = 181/255.0
          RB(680) = 181/255.0
          CNAME(680) = 'GREY71'
          RR(681) = 184/255.0
          RG(681) = 184/255.0
          RB(681) = 184/255.0
          CNAME(681) = 'GRAY72'
          RR(682) = 184/255.0
          RG(682) = 184/255.0
          RB(682) = 184/255.0
          CNAME(682) = 'GREY72'
          RR(683) = 186/255.0
          RG(683) = 186/255.0
          RB(683) = 186/255.0
          CNAME(683) = 'GRAY73'
          RR(684) = 186/255.0
          RG(684) = 186/255.0
          RB(684) = 186/255.0
          CNAME(684) = 'GREY73'
          RR(685) = 189/255.0
          RG(685) = 189/255.0
          RB(685) = 189/255.0
          CNAME(685) = 'GRAY74'
          RR(686) = 189/255.0
          RG(686) = 189/255.0
          RB(686) = 189/255.0
          CNAME(686) = 'GREY74'
          RR(687) = 191/255.0
          RG(687) = 191/255.0
          RB(687) = 191/255.0
          CNAME(687) = 'GRAY75'
          RR(688) = 191/255.0
          RG(688) = 191/255.0
          RB(688) = 191/255.0
          CNAME(688) = 'GREY75'
          RR(689) = 194/255.0
          RG(689) = 194/255.0
          RB(689) = 194/255.0
          CNAME(689) = 'GRAY76'
          RR(690) = 194/255.0
          RG(690) = 194/255.0
          RB(690) = 194/255.0
          CNAME(690) = 'GREY76'
          RR(691) = 196/255.0
          RG(691) = 196/255.0
          RB(691) = 196/255.0
          CNAME(691) = 'GRAY77'
          RR(692) = 196/255.0
          RG(692) = 196/255.0
          RB(692) = 196/255.0
          CNAME(692) = 'GREY77'
          RR(693) = 199/255.0
          RG(693) = 199/255.0
          RB(693) = 199/255.0
          CNAME(693) = 'GRAY78'
          RR(694) = 199/255.0
          RG(694) = 199/255.0
          RB(694) = 199/255.0
          CNAME(694) = 'GREY78'
          RR(695) = 201/255.0
          RG(695) = 201/255.0
          RB(695) = 201/255.0
          CNAME(695) = 'GRAY79'
          RR(696) = 201/255.0
          RG(696) = 201/255.0
          RB(696) = 201/255.0
          CNAME(696) = 'GREY79'
          RR(697) = 204/255.0
          RG(697) = 204/255.0
          RB(697) = 204/255.0
          CNAME(697) = 'GRAY80'
          RR(698) = 204/255.0
          RG(698) = 204/255.0
          RB(698) = 204/255.0
          CNAME(698) = 'GREY80'
          RR(699) = 207/255.0
          RG(699) = 207/255.0
          RB(699) = 207/255.0
          CNAME(699) = 'GRAY81'
          RR(700) = 207/255.0
          RG(700) = 207/255.0
          RB(700) = 207/255.0
          CNAME(700) = 'GREY81'
          RR(701) = 209/255.0
          RG(701) = 209/255.0
          RB(701) = 209/255.0
          CNAME(701) = 'GRAY82'
          RR(702) = 209/255.0
          RG(702) = 209/255.0
          RB(702) = 209/255.0
          CNAME(702) = 'GREY82'
          RR(703) = 212/255.0
          RG(703) = 212/255.0
          RB(703) = 212/255.0
          CNAME(703) = 'GRAY83'
          RR(704) = 212/255.0
          RG(704) = 212/255.0
          RB(704) = 212/255.0
          CNAME(704) = 'GREY83'
          RR(705) = 214/255.0
          RG(705) = 214/255.0
          RB(705) = 214/255.0
          CNAME(705) = 'GRAY84'
          RR(706) = 214/255.0
          RG(706) = 214/255.0
          RB(706) = 214/255.0
          CNAME(706) = 'GREY84'
          RR(707) = 217/255.0
          RG(707) = 217/255.0
          RB(707) = 217/255.0
          CNAME(707) = 'GRAY85'
          RR(708) = 217/255.0
          RG(708) = 217/255.0
          RB(708) = 217/255.0
          CNAME(708) = 'GREY85'
          RR(709) = 219/255.0
          RG(709) = 219/255.0
          RB(709) = 219/255.0
          CNAME(709) = 'GRAY86'
          RR(710) = 219/255.0
          RG(710) = 219/255.0
          RB(710) = 219/255.0
          CNAME(710) = 'GREY86'
          RR(711) = 222/255.0
          RG(711) = 222/255.0
          RB(711) = 222/255.0
          CNAME(711) = 'GRAY87'
          RR(712) = 222/255.0
          RG(712) = 222/255.0
          RB(712) = 222/255.0
          CNAME(712) = 'GREY87'
          RR(713) = 224/255.0
          RG(713) = 224/255.0
          RB(713) = 224/255.0
          CNAME(713) = 'GRAY88'
          RR(714) = 224/255.0
          RG(714) = 224/255.0
          RB(714) = 224/255.0
          CNAME(714) = 'GREY88'
          RR(715) = 227/255.0
          RG(715) = 227/255.0
          RB(715) = 227/255.0
          CNAME(715) = 'GRAY89'
          RR(716) = 227/255.0
          RG(716) = 227/255.0
          RB(716) = 227/255.0
          CNAME(716) = 'GREY89'
          RR(717) = 229/255.0
          RG(717) = 229/255.0
          RB(717) = 229/255.0
          CNAME(717) = 'GRAY90'
          RR(718) = 229/255.0
          RG(718) = 229/255.0
          RB(718) = 229/255.0
          CNAME(718) = 'GREY90'
          RR(719) = 232/255.0
          RG(719) = 232/255.0
          RB(719) = 232/255.0
          CNAME(719) = 'GRAY91'
          RR(720) = 232/255.0
          RG(720) = 232/255.0
          RB(720) = 232/255.0
          CNAME(720) = 'GREY91'
          RR(721) = 235/255.0
          RG(721) = 235/255.0
          RB(721) = 235/255.0
          CNAME(721) = 'GRAY92'
          RR(722) = 235/255.0
          RG(722) = 235/255.0
          RB(722) = 235/255.0
          CNAME(722) = 'GREY92'
          RR(723) = 237/255.0
          RG(723) = 237/255.0
          RB(723) = 237/255.0
          CNAME(723) = 'GRAY93'
          RR(724) = 237/255.0
          RG(724) = 237/255.0
          RB(724) = 237/255.0
          CNAME(724) = 'GREY93'
          RR(725) = 240/255.0
          RG(725) = 240/255.0
          RB(725) = 240/255.0
          CNAME(725) = 'GRAY94'
          RR(726) = 240/255.0
          RG(726) = 240/255.0
          RB(726) = 240/255.0
          CNAME(726) = 'GREY94'
          RR(727) = 242/255.0
          RG(727) = 242/255.0
          RB(727) = 242/255.0
          CNAME(727) = 'GRAY95'
          RR(728) = 242/255.0
          RG(728) = 242/255.0
          RB(728) = 242/255.0
          CNAME(728) = 'GREY95'
          RR(729) = 245/255.0
          RG(729) = 245/255.0
          RB(729) = 245/255.0
          CNAME(729) = 'GRAY96'
          RR(730) = 245/255.0
          RG(730) = 245/255.0
          RB(730) = 245/255.0
          CNAME(730) = 'GREY96'
          RR(731) = 247/255.0
          RG(731) = 247/255.0
          RB(731) = 247/255.0
          CNAME(731) = 'GRAY97'
          RR(732) = 247/255.0
          RG(732) = 247/255.0
          RB(732) = 247/255.0
          CNAME(732) = 'GREY97'
          RR(733) = 250/255.0
          RG(733) = 250/255.0
          RB(733) = 250/255.0
          CNAME(733) = 'GRAY98'
          RR(734) = 250/255.0
          RG(734) = 250/255.0
          RB(734) = 250/255.0
          CNAME(734) = 'GREY98'
          RR(735) = 252/255.0
          RG(735) = 252/255.0
          RB(735) = 252/255.0
          CNAME(735) = 'GRAY99'
          RR(736) = 252/255.0
          RG(736) = 252/255.0
          RB(736) = 252/255.0
          CNAME(736) = 'GREY99'
          RR(737) = 255/255.0
          RG(737) = 255/255.0
          RB(737) = 255/255.0
          CNAME(737) = 'GRAY100'
          RR(738) = 255/255.0
          RG(738) = 255/255.0
          RB(738) = 255/255.0
          CNAME(738) = 'GREY100'
          NCOL = 738
      END IF
C
C Look up requested color and set color representation if found.
C
      CALL GRTOUP(CREQ, NAME)
      DO 20 I=1,NCOL
          IF (CREQ.EQ.CNAME(I)) THEN
              CALL PGSCR(CI, RR(I), RG(I), RB(I))
              IER = 0
              RETURN
          END IF
   20 CONTINUE
C
C Color not found.
C
      IER = 1
      TEXT = 'Color not found: '//NAME
      CALL GRWARN(TEXT)
      RETURN
C
C Database not found.
C
   40 IER = 1
      NCOL = -1
      CALL GRFLUN(UNIT)
      CALL GRWARN('Unable to read color file: '//TEXT(1:L))
      CALL GRWARN('Use environment variable PGPLOT_RGB to specify '//
     :            'the location of the PGPLOT rgb.txt file.')
      RETURN
      END
